diff --git a/include/cantera/equil/vcs_VolPhase.h b/include/cantera/equil/vcs_VolPhase.h
index 972ed1da3..05ca65820 100644
--- a/include/cantera/equil/vcs_VolPhase.h
+++ b/include/cantera/equil/vcs_VolPhase.h
@@ -72,7 +72,7 @@ class VCS_SOLVE;
* with it. This object helps to coordinate property evaluations for
* species within the phase. Usually these evaluations must be carried
* out on a per phase basis. However, vcs frequently needs per species
- * quantitites. Therefore, we need an interface layer between vcs
+ * quantities. Therefore, we need an interface layer between vcs
* and Cantera's ThermoPhase.
*
* The species stay in the same ordering within this structure.
@@ -87,19 +87,19 @@ class VCS_SOLVE;
*
* This object contains an idea of the temperature and pressure.
* It checks to see if if the temperature and pressure has changed before calling
- * underlying property evalulation routines.
+ * underlying property evaluation routines.
*
* The object contains values for the electric potential of a phase.
- * It coordinates the evalulation of properties wrt when the electric
+ * It coordinates the evaluation of properties wrt when the electric
* potential of a phase has changed.
*
* The object knows about the mole fractions of the phase. It controls
- * the values of mole fractions, and coordinates the property evalulation
+ * the values of mole fractions, and coordinates the property evaluation
* wrt to changes in the mole fractions. It also will keep track of the
* likely values of mole fractions in multicomponent phases even when
* the phase doesn't actually exist within the thermo program.
*
- * The object knows about the total moles of a phase. It checkes to
+ * The object knows about the total moles of a phase. It checks to
* see if the phase currently exists or not, and modifies its behavior
* accordingly.
*
@@ -629,7 +629,7 @@ private:
//! Calculate the partial molar volumes of all species and return the
//! total volume
/*!
- * Calculates these quantitites internally
+ * Calculates these quantities internally
*
* @return total volume
*/
@@ -650,7 +650,7 @@ private:
*/
void _updateLnActCoeffJac();
- //! Updates the mole fraction depenpencies
+ //! Updates the mole fraction dependencies
/*!
* Whenever the mole fractions change, this routine
* should be called.
@@ -717,7 +717,7 @@ public:
//! and species amounts
/*!
* All internally stored quantities will have these units. Also, printed
- * quantitities will display in these units. Input quantities are expected
+ * quantities will display in these units. Input quantities are expected
* in these units.
*
* Chem_Pot Pres vol moles
@@ -889,7 +889,7 @@ private:
* The phase stability problem requires a global reaction number for each
* species in the phase. Usually this is the krxn = kglob - M for species
* in the phase that are not components. For component species, the
- * choice of the reaction is one which maximimes the chance that the phase
+ * choice of the reaction is one which maximizes the chance that the phase
* pops into (or remains in) existence.
* The index here is the local phase species index.
* the value of the variable is the global vcs reaction number. Note,
@@ -972,11 +972,11 @@ private:
//! Value of the potential for the phase (Volts)
double m_phi;
- //! Boolean indicating whether the object has an uptodate mole number vector
+ //! Boolean indicating whether the object has an up-to-date mole number vector
//! and potential with respect to the current vcs state calc status
bool m_UpToDate;
- //! Boolean indicating whether activity coefficients are uptodate.
+ //! Boolean indicating whether activity coefficients are up to date.
/*!
* Activity coefficients and volume calculations are lagged. They are only
* called when they are needed (and when the state has changed so that they
@@ -984,7 +984,7 @@ private:
*/
mutable bool m_UpToDate_AC;
- //! Boolean indicating whether Star volumes are uptodate.
+ //! Boolean indicating whether Star volumes are up to date.
/*!
* Activity coefficients and volume calculations are lagged. They are only
* called when they are needed (and when the state has changed so that they
@@ -993,7 +993,7 @@ private:
*/
mutable bool m_UpToDate_VolStar;
- //! Boolean indicating whether partial molar volumes are uptodate.
+ //! Boolean indicating whether partial molar volumes are up to date.
/*!
* Activity coefficients and volume calculations are lagged. They are only
* called when they are needed (and when the state has changed so that they
@@ -1002,14 +1002,14 @@ private:
*/
mutable bool m_UpToDate_VolPM;
- //! Boolean indicating whether GStar is uptodate.
+ //! Boolean indicating whether GStar is up to date.
/*!
* GStar is sensitive to the temperature and the pressure, only
*/
mutable bool m_UpToDate_GStar;
- //! Boolean indicating whether G0 is uptodate.
+ //! Boolean indicating whether G0 is up to date.
/*!
* G0 is sensitive to the temperature and the pressure, only
*/
diff --git a/include/cantera/equil/vcs_internal.h b/include/cantera/equil/vcs_internal.h
index c4df5bd61..a2bb96a3b 100644
--- a/include/cantera/equil/vcs_internal.h
+++ b/include/cantera/equil/vcs_internal.h
@@ -137,7 +137,7 @@ double vcsUtil_gasConstant(int mu_units);
*
* @return The solution x[] is returned in the matrix B.
* Routine returns an integer representing success:
- * - 1 : Matrix is singluar
+ * - 1 : Matrix is singular
* - 0 : solution is OK
*
*
@@ -174,7 +174,7 @@ int vcsUtil_mlequ(double* c, size_t idem, size_t n, double* b, size_t m);
*
* @return The solution x[] is returned in the matrix B.
* Routine returns an integer representing success:
- * - 1 : Matrix is singluar
+ * - 1 : Matrix is singular
* - 0 : solution is OK
*
* @param c Matrix to be inverted. c is in fortran format, i.e., rows
@@ -233,7 +233,7 @@ typedef double(*VCS_FUNC_PTR)(double xval, double Vtarget,
* f(xval).
*
* @param xmin Minimum permissible value of the x variable
- * @param xmax Maximum permissible value of the x paramerer
+ * @param xmax Maximum permissible value of the x parameter
* @param itmax Maximum number of iterations
* @param func function pointer, pointing to the function to be
* minimized
@@ -476,7 +476,7 @@ size_t vcs_optMax(const double* x, const double* xSize, size_t j, size_t n);
*/
int vcs_max_int(const int* vector, int length);
-//! Prints a line consisting of mutliple occurances of the same string
+//! Prints a line consisting of multiple occurrences of the same string
/*!
* This prints a string num times, and then terminate with a
* end of line character
diff --git a/include/cantera/equil/vcs_prob.h b/include/cantera/equil/vcs_prob.h
index a8ef0325b..23cedf805 100644
--- a/include/cantera/equil/vcs_prob.h
+++ b/include/cantera/equil/vcs_prob.h
@@ -27,7 +27,7 @@ class VCS_SPECIES_THERMO;
//! which generally describes the problem to be solved.
/*!
* HKM add:
- * HaveEstimate -> 0 no estimate, or estimate that doesn' satisfy elem
+ * HaveEstimate -> 0 no estimate, or estimate that doesn't satisfy elem
* abundances
* 1 have an estimate that satisfies elem_abund.
* 2 Have an estimate that minimizes a subproblem
@@ -116,7 +116,7 @@ public:
* unknown. The second is the an interfacial
* voltage where w[k] refers to the interfacial
* voltage in volts.
- * These species types correspond to metalic
+ * These species types correspond to metallic
* electrons corresponding to electrodes.
* The voltage and other interfacial conditions
* sets up an interfacial current, which is
@@ -157,7 +157,7 @@ public:
//! and species amounts
/*!
* All internally stored quantities will have these units. Also, printed
- * quantitities will display in these units.
+ * quantities will display in these units.
*
* Chem_Pot Pres vol moles
* ----------------------------------------------------------------------
diff --git a/include/cantera/equil/vcs_solve.h b/include/cantera/equil/vcs_solve.h
index af91a8b2b..b0e1921b2 100644
--- a/include/cantera/equil/vcs_solve.h
+++ b/include/cantera/equil/vcs_solve.h
@@ -1059,7 +1059,7 @@ public:
int vcs_inest_TP();
#ifdef ALTLINPROG
- //! Extimate the initial mole numbers by constrained linear programming
+ //! Estimate the initial mole numbers by constrained linear programming
/*!
* This is done by running
* each reaction as far forward or backward as possible, subject
@@ -1497,7 +1497,7 @@ public:
/*!
* FormulaMatrix[j][kspec] = Number of elements, j, in the kspec species
*
- * Both element and species indecies are swapped.
+ * Both element and species indices are swapped.
*/
DoubleStarStar m_formulaMatrix;
@@ -1511,7 +1511,7 @@ public:
*
* m_stoichCoeffRxnMatrix[irxn][j] :
* j refers to the component number, and irxn refers to the irxn_th non-component species.
- * The stoichiometric coefficents multilpled by the Formula coefficients of the
+ * The stoichiometric coefficients multilplied by the Formula coefficients of the
* component species add up to the negative value of the number of elements in
* the species kspec.
*
@@ -1585,7 +1585,7 @@ public:
* unknown. The second is the an interfacial
* voltage where w[k] refers to the interfacial
* voltage in volts.
- * These species types correspond to metalic
+ * These species types correspond to metallic
* electrons corresponding to electrodes.
* The voltage and other interfacial conditions
* sets up an interfacial current, which is
diff --git a/include/cantera/numerics/BandMatrix.h b/include/cantera/numerics/BandMatrix.h
index c737562e7..f6d1fa3b7 100644
--- a/include/cantera/numerics/BandMatrix.h
+++ b/include/cantera/numerics/BandMatrix.h
@@ -187,14 +187,14 @@ public:
//! Multiply A*b and write result to prod.
/*!
- * @param b Vector to do the rh multiplcation
+ * @param b Vector to do the rh multiplication
* @param prod OUTPUT vector to receive the result
*/
virtual void mult(const doublereal* b, doublereal* prod) const;
//! Multiply b*A and write result to prod.
/*!
- * @param b Vector to do the lh multiplcation
+ * @param b Vector to do the lh multiplication
* @param prod OUTPUT vector to receive the result
*/
virtual void leftMult(const doublereal* const b, doublereal* const prod) const;
diff --git a/include/cantera/numerics/GeneralMatrix.h b/include/cantera/numerics/GeneralMatrix.h
index 21fca08f5..20524a479 100644
--- a/include/cantera/numerics/GeneralMatrix.h
+++ b/include/cantera/numerics/GeneralMatrix.h
@@ -59,14 +59,14 @@ public:
//! Multiply A*b and write result to prod.
/*!
- * @param b Vector to do the rh multiplcation
+ * @param b Vector to do the rh multiplication
* @param prod OUTPUT vector to receive the result
*/
virtual void mult(const doublereal* b, doublereal* prod) const = 0;
//! Multiply b*A and write result to prod.
/*!
- * @param b Vector to do the lh multiplcation
+ * @param b Vector to do the lh multiplication
* @param prod OUTPUT vector to receive the result
*/
virtual void leftMult(const doublereal* const b, doublereal* const prod) const = 0;
diff --git a/include/cantera/numerics/NonlinearSolver.h b/include/cantera/numerics/NonlinearSolver.h
index 610de65eb..911d05581 100644
--- a/include/cantera/numerics/NonlinearSolver.h
+++ b/include/cantera/numerics/NonlinearSolver.h
@@ -221,7 +221,7 @@ public:
* @param typeCalc Type of the calculation
* @param y_curr Current value of the solution vector
* @param ydot_curr Current value of the time derivative of the solution vector
- * @param evalType Base evalulation type
+ * @param evalType Base evaluation type
* Defaults to Base_ResidEval
*
* @return Returns a flag to indicate that operation is successful.
diff --git a/include/cantera/numerics/ResidJacEval.h b/include/cantera/numerics/ResidJacEval.h
index 4e6801cb4..bec41ffda 100644
--- a/include/cantera/numerics/ResidJacEval.h
+++ b/include/cantera/numerics/ResidJacEval.h
@@ -313,7 +313,7 @@ public:
*
* @param t Time (input)
* @param delta_t The current value of the time step (input)
- * @param cj Coefficient of yprime used in the evalulation of the jacobian
+ * @param cj Coefficient of yprime used in the evaluation of the jacobian
* @param y Solution vector (input, do not modify)
* @param ydot Rate of change of solution vector. (input, do not modify)
* @param J Reference to the SquareMatrix object to be calculated (output)
@@ -334,7 +334,7 @@ public:
*
* @param t Time (input)
* @param delta_t The current value of the time step (input)
- * @param cj Coefficient of yprime used in the evalulation of the jacobian
+ * @param cj Coefficient of yprime used in the evaluation of the jacobian
* @param y Solution vector (input, do not modify)
* @param ydot Rate of change of solution vector. (input, do not modify)
* @param jacobianColPts Pointer to the vector of pts to columns of the SquareMatrix
diff --git a/include/cantera/numerics/RootFind.h b/include/cantera/numerics/RootFind.h
index 03c51afd6..15958c098 100644
--- a/include/cantera/numerics/RootFind.h
+++ b/include/cantera/numerics/RootFind.h
@@ -188,7 +188,7 @@ private:
*/
doublereal delXMeaningful(doublereal x1) const;
- //! Calcuated a controlled, nonzero delta between two numbers
+ //! Calculate a controlled, nonzero delta between two numbers
/*!
* The delta is designed to be greater than or equal to delXMeaningful(x) defined above
* with the same sign as the original delta. Therefore if you subtract it from either
diff --git a/include/cantera/numerics/SquareMatrix.h b/include/cantera/numerics/SquareMatrix.h
index 02757b76a..34e3d869b 100644
--- a/include/cantera/numerics/SquareMatrix.h
+++ b/include/cantera/numerics/SquareMatrix.h
@@ -78,14 +78,14 @@ public:
//! Multiply A*b and write result to prod.
/*!
- * @param b Vector to do the rh multiplcation
+ * @param b Vector to do the rh multiplication
* @param prod OUTPUT vector to receive the result
*/
virtual void mult(const doublereal* b, doublereal* prod) const;
//! Multiply b*A and write result to prod.
/*!
- * @param b Vector to do the lh multiplcation
+ * @param b Vector to do the lh multiplication
* @param prod OUTPUT vector to receive the result
*/
virtual void leftMult(const doublereal* const b, doublereal* const prod) const;
diff --git a/include/cantera/numerics/solveProb.h b/include/cantera/numerics/solveProb.h
index d34ab5f6b..9d1e81086 100644
--- a/include/cantera/numerics/solveProb.h
+++ b/include/cantera/numerics/solveProb.h
@@ -45,7 +45,7 @@
* initial guess, and accuracy is needed.
* 4: SOLVEPROB_TRANSIENT = The transient calculation is performed here for an
* amount of time specified by "time_scale". It is
- * not garraunted to be time-accurate - just stable
+ * not guaranteed to be time-accurate - just stable
* and fairly fast. The solution after del_t time is
* returned, whether it's converged to a steady
* state or not.
@@ -113,13 +113,13 @@ namespace Cantera
*
* 4: SOLVEPROB_TRANSIENT = The transient calculation is performed here for an
* amount of time specified by "time_scale". It is
- * not garraunted to be time-accurate - just stable
+ * not guaranteed to be time-accurate - just stable
* and fairly fast. The solution after del_t time is
* returned, whether it's converged to a steady
* state or not. This is a poor man's time stepping
* algorithm.
*
- * Psuedo time stepping algorithm:
+ * Pseudo time stepping algorithm:
* The time step is determined from sdot[], so that the time step
* doesn't ever change the value of a variable by more than 100%.
*
@@ -302,7 +302,7 @@ private:
* @param damp lvl of damping
* @param inv_t Inverse of the value of delta T
* @param t_real Value of the time
- * @param iter Interation number
+ * @param iter Iteration number
* @param do_time boolean indicating whether time stepping is taking
* place
*/
@@ -311,7 +311,7 @@ private:
bool do_time);
#endif
- //! Main Function evalulation
+ //! Main Function evaluation
/*!
*
* @param resid output Vector of residuals, length = m_neq
@@ -344,7 +344,7 @@ private:
const doublereal deltaT);
//! This function calculates a damping factor for the Newton iteration update
- //! vector, dxneg, to insure that all solution components stay within perscribed bounds
+ //! vector, dxneg, to insure that all solution components stay within prescribed bounds
/*!
* The default for this class is that all solution components are bounded between zero and one.
* this is because the original unknowns were mole fractions and surface site fractions.
diff --git a/include/cantera/thermo/DebyeHuckel.h b/include/cantera/thermo/DebyeHuckel.h
index 8504c1026..8e2edb4ff 100644
--- a/include/cantera/thermo/DebyeHuckel.h
+++ b/include/cantera/thermo/DebyeHuckel.h
@@ -207,11 +207,11 @@ class PDSS_Water;
* It may or may not be charged. These may or
* may not be be included in the
* species solution vector.
- * - cEST_strongAcidAssociated Species which always breaksapart into charged species.
+ * - cEST_strongAcidAssociated Species which always breaks apart into charged species.
* It may or may not be charged. Normally, these aren't included
* in the speciation vector.
* - cEST_polarNeutral Polar neutral species
- * - cEST_nonpolarNeutral Non poloar neutral species
+ * - cEST_nonpolarNeutral Non polar neutral species
*
* Polar and non-polar neutral species are differentiated, because some additions
* to the activity
@@ -236,7 +236,7 @@ class PDSS_Water;
*
* @endcode
*
- * Much of the species electrolyte type information is infered from other information in the
+ * Much of the species electrolyte type information is inferred from other information in the
* input file. For example, as species which is charged is given the "chargedSpecies" default
* category. A neutral solute species is put into the "nonpolarNeutral" category by default.
*
@@ -428,12 +428,12 @@ class PDSS_Water;
* Units = sqrt(kg/gmol)
*
* where
- * - \f$ N_a \f$ is Avrogadro's number
+ * - \f$ N_a \f$ is Avogadro's number
* - \f$ \rho_w \f$ is the density of water
* - \f$ e \f$ is the electronic charge
- * - \f$ \epsilon = K \epsilon_o \f$ is the permitivity of water
- * where \f$ K \f$ is the dielectric condstant of water,
- * and \f$ \epsilon_o \f$ is the permitivity of free space.
+ * - \f$ \epsilon = K \epsilon_o \f$ is the permittivity of water
+ * where \f$ K \f$ is the dielectric constant of water,
+ * and \f$ \epsilon_o \f$ is the permittivity of free space.
* - \f$ \rho_o \f$ is the density of the solvent in its standard state.
*
* Nominal value at 298 K and 1 atm = 1.172576 (kg/gmol)1/2
@@ -1215,7 +1215,7 @@ public:
//! Get the saturation pressure for a given temperature.
/*!
* Note the limitations of this function. Stability considerations
- * concernting multiphase equilibrium are ignored in this
+ * concerning multiphase equilibrium are ignored in this
* calculation. Therefore, the call is made directly to the SS of
* water underneath. The object is put back into its original
* state at the end of the call.
@@ -1360,12 +1360,12 @@ public:
* Units = sqrt(kg/gmol)
*
* where
- * - \f$ N_a \f$ is Avrogadro's number
+ * - \f$ N_a \f$ is Avogadro's number
* - \f$ \rho_w \f$ is the density of water
* - \f$ e \f$ is the electronic charge
- * - \f$ \epsilon = K \epsilon_o \f$ is the permitivity of water
- * where \f$ K \f$ is the dielectric condstant of water,
- * and \f$ \epsilon_o \f$ is the permitivity of free space.
+ * - \f$ \epsilon = K \epsilon_o \f$ is the permittivity of water
+ * where \f$ K \f$ is the dielectric constant of water,
+ * and \f$ \epsilon_o \f$ is the permittivity of free space.
* = \f$ \rho_o \f$ is the density of the solvent in its standard state.
*
* Nominal value at 298 K and 1 atm = 1.172576 (kg/gmol)1/2
@@ -1570,7 +1570,7 @@ public:
/**
* If true, then the fixed for of Helgeson's activity
- * for water is used instead of the rigoruous form
+ * for water is used instead of the rigorous form
* obtained from Gibbs-Duhem relation. This should be
* used with caution, and is really only included as a
* validation exercise.
@@ -1652,7 +1652,7 @@ protected:
*/
double m_B_Debye;
- //! Array of B_Dot valyes
+ //! Array of B_Dot values
/**
* B_Dot -> This expression is an extension of the
* Debye-Huckel expression used in some formulations
diff --git a/include/cantera/thermo/Elements.h b/include/cantera/thermo/Elements.h
index ac2cd8800..9e94f016d 100644
--- a/include/cantera/thermo/Elements.h
+++ b/include/cantera/thermo/Elements.h
@@ -132,7 +132,7 @@ public:
*/
Elements(const Elements& right);
- //! Assigntment operator
+ //! Assignment operator
/*!
* This is the assignment operator for the Elements class.
* Right now we pretty much do a straight uncomplicated
diff --git a/include/cantera/thermo/FixedChemPotSSTP.h b/include/cantera/thermo/FixedChemPotSSTP.h
index be234e06f..f73e61ebb 100644
--- a/include/cantera/thermo/FixedChemPotSSTP.h
+++ b/include/cantera/thermo/FixedChemPotSSTP.h
@@ -70,9 +70,9 @@ namespace Cantera
* appear in the rate constant expression, since it's a stoichiometric
* phase, and the activity is always equal to 1.0.
*
- * Instanteation of the Class
+ * Instantiation of the Class
*
- * This phase may be instanteated by calling the default ThermoFactory routine
+ * This phase may be instantiated by calling the default ThermoFactory routine
* for %Cantera. This new %FixedChemPotSSTP object must then have a standalone xml file
* description an example of which is given below.
*
@@ -301,7 +301,7 @@ public:
* by kinetics manager classes to compute the forward and
* reverse rates of elementary reactions.
*
- * For a stoichiomeetric substance, there is
+ * For a stoichiometric substance, there is
* only one species, and the generalized concentration is 1.0.
*
* @param c Output array of generalized concentrations. The
@@ -358,7 +358,7 @@ public:
* units are needed. Usually, MKS units are assumed throughout
* the program and in the XML input files.
*
- * The base %ThermoPhase class assigns thedefault quantities
+ * The base %ThermoPhase class assigns the default quantities
* of (kmol/m3) for all species.
* Inherited classes are responsible for overriding the default
* values if necessary.
diff --git a/include/cantera/thermo/HMWSoln.h b/include/cantera/thermo/HMWSoln.h
index a00c54b46..9cec17f31 100644
--- a/include/cantera/thermo/HMWSoln.h
+++ b/include/cantera/thermo/HMWSoln.h
@@ -189,7 +189,7 @@ class PDSS_Water;
* The redundancy issue is resolved by setting the standard state chemical potential
* enthalpy, entropy, and volume for the hydrogen ion, H+, to zero, for every temperature
* and pressure. After this convention is applied, all other standard state
- * properties of ionic species contain meaningfull information.
+ * properties of ionic species contain meaningful information.
*
*
*
Ionic Strength
@@ -265,11 +265,11 @@ class PDSS_Water;
* It may or may not be charged. These may or
* may not be be included in the
* species solution vector.
- * - cEST_strongAcidAssociated Species which always breaksapart into charged species.
+ * - cEST_strongAcidAssociated Species which always breaks apart into charged species.
* It may or may not be charged. Normally, these
* aren't included in the speciation vector.
* - cEST_polarNeutral Polar neutral species
- * - cEST_nonpolarNeutral Non poloar neutral species
+ * - cEST_nonpolarNeutral Non polar neutral species
*
* Polar and non-polar neutral species are differentiated, because some additions
* to the activity
@@ -295,7 +295,7 @@ class PDSS_Water;
* @endcode
*
*
- * Much of the species electrolyte type information is infered from other information in the
+ * Much of the species electrolyte type information is inferred from other information in the
* input file. For example, as species which is charged is given the "chargedSpecies" default
* category. A neutral solute species is put into the "nonpolarNeutral" category by default.
*
@@ -319,7 +319,7 @@ class PDSS_Water;
*
* From the excess Gibbs free energy formulation, the activity coefficient expression
* and the osmotic coefficient expression for the solvent may be defined, by
- * taking the appropriate derivatives. Using this approach garranties that the
+ * taking the appropriate derivatives. Using this approach guarantees that the
* entire system will obey the Gibbs-Duhem relations.
*
* Pitzer employs the following general expression for the excess Gibbs free energy
@@ -348,7 +348,7 @@ class PDSS_Water;
* and anions affect anions or cation/anion pairs. Note part of the coefficients,
* \f$ \Phi_{c{c'}} \f$ and \f$ \Phi_{a{a'}} \f$ stem from the theory
* of unsymmetrical mixing of electrolytes with different charges. This
- * theory depends on the total ionic stregnth of the solution, and therefore,
+ * theory depends on the total ionic strength of the solution, and therefore,
* \f$ \Phi_{c{c'}} \f$ and \f$ \Phi_{a{a'}} \f$ will depend on I, the
* ionic strength. \f$ B_{ca}\f$ is a strong function of the
* total ionic strength, I,
@@ -580,7 +580,7 @@ class PDSS_Water;
* HMWSoln has an implementation described by Silverter and Pitzer (1977),
* which was used to fit experimental data for NaCl over an extensive range,
* below the critical temperature of water.
- * They found a temperature funcdtional form for fitting the 3 following
+ * They found a temperature functional form for fitting the 3 following
* coefficients that describe the Pitzer parameterization for a single salt
* to be adequate to describe how the excess gibbs free energy values for
* the binary salt changes with respect to temperature.
@@ -653,7 +653,7 @@ class PDSS_Water;
* \f$\alpha^{(2)}_{MX} \f$.
* \f$ C_{MX}\f$ is calculated from \f$C^{\phi}_{MX} \f$
* from the formula above.
- * All of the underlying coeficients are specified in the
+ * All of the underlying coefficients are specified in the
* XML element block binarySaltParameters , which
* has the attribute cation and anion
* to identify the interaction. XML elements named
@@ -907,12 +907,12 @@ class PDSS_Water;
* Units = sqrt(kg/gmol)
*
* where
- * - \f$ N_a \f$ is Avrogadro's number
+ * - \f$ N_a \f$ is Avogadro's number
* - \f$ \rho_w \f$ is the density of water
* - \f$ e \f$ is the electronic charge
- * - \f$ \epsilon = K \epsilon_o \f$ is the permitivity of water
+ * - \f$ \epsilon = K \epsilon_o \f$ is the permittivity of water
* where \f$ K \f$ is the dielectric constant of water,
- * and \f$ \epsilon_o \f$ is the permitivity of free space.
+ * and \f$ \epsilon_o \f$ is thepermittivityy of free space.
* - \f$ \rho_o \f$ is the density of the solvent in its standard state.
*
* Nominal value at 298 K and 1 atm = 1.172576 (kg/gmol)1/2
@@ -2019,7 +2019,7 @@ public:
//! Get the saturation pressure for a given temperature.
/*!
* Note the limitations of this function. Stability considerations
- * concernting multiphase equilibrium are ignored in this
+ * concerning multiphase equilibrium are ignored in this
* calculation. Therefore, the call is made directly to the SS of
* water underneath. The object is put back into its original
* state at the end of the call.
@@ -2156,7 +2156,7 @@ public:
* @param temperature Temperature of the derivative calculation
* or -1 to indicate the current temperature
*
- * @param pressure Pressure of the derivative calcualtion
+ * @param pressure Pressure of the derivative calculation
* or -1 to indicate the current pressure
*/
virtual double A_Debye_TP(double temperature = -1.0,
@@ -2174,7 +2174,7 @@ public:
* @param temperature Temperature of the derivative calculation
* or -1 to indicate the current temperature
*
- * @param pressure Pressure of the derivative calcualtion
+ * @param pressure Pressure of the derivative calculation
* or -1 to indicate the current pressure
*/
virtual double dA_DebyedT_TP(double temperature = -1.0,
@@ -2192,7 +2192,7 @@ public:
* @param temperature Temperature of the derivative calculation
* or -1 to indicate the current temperature
*
- * @param pressure Pressure of the derivative calcualtion
+ * @param pressure Pressure of the derivative calculation
* or -1 to indicate the current pressure
*/
virtual double dA_DebyedP_TP(double temperature = -1.0,
@@ -2212,7 +2212,7 @@ public:
* @param temperature Temperature of the derivative calculation
* or -1 to indicate the current temperature
*
- * @param pressure Pressure of the derivative calcualtion
+ * @param pressure Pressure of the derivative calculation
* or -1 to indicate the current pressure
*/
double ADebye_L(double temperature = -1.0,
@@ -2232,7 +2232,7 @@ public:
* @param temperature Temperature of the derivative calculation
* or -1 to indicate the current temperature
*
- * @param pressure Pressure of the derivative calcualtion
+ * @param pressure Pressure of the derivative calculation
* or -1 to indicate the current pressure
*/
double ADebye_J(double temperature = -1.0,
@@ -2250,7 +2250,7 @@ public:
* @param temperature Temperature of the derivative calculation
* or -1 to indicate the current temperature
*
- * @param pressure Pressure of the derivative calcualtion
+ * @param pressure Pressure of the derivative calculation
* or -1 to indicate the current pressure
*
*/
@@ -2269,7 +2269,7 @@ public:
* @param temperature Temperature of the derivative calculation
* or -1 to indicate the current temperature
*
- * @param pressure Pressure of the derivative calcualtion
+ * @param pressure Pressure of the derivative calculation
* or -1 to indicate the current pressure
*/
virtual double d2A_DebyedT2_TP(double temperature = -1.0,
@@ -2809,19 +2809,19 @@ private:
*/
mutable vector_fp m_Psi_ijk;
- //! Derivitive of Psi_ijk[n] wrt T
+ //! Derivative of Psi_ijk[n] wrt T
/*!
* see m_Psi_ijk for reference on the indexing into this variable.
*/
mutable vector_fp m_Psi_ijk_L;
- //! Derivitive of Psi_ijk[n] wrt TT
+ //! Derivative of Psi_ijk[n] wrt TT
/*!
* see m_Psi_ijk for reference on the indexing into this variable.
*/
mutable vector_fp m_Psi_ijk_LL;
- //! Derivitive of Psi_ijk[n] wrt P
+ //! Derivative of Psi_ijk[n] wrt P
/*!
* see m_Psi_ijk for reference on the indexing into this variable.
*/
@@ -3223,7 +3223,7 @@ private:
//! gamma_o value for the cutoff process at the zero solvent point
doublereal IMS_gamma_o_min_;
- //! gamma_k minimun for the cutoff process at the zero solvent point
+ //! gamma_k minimum for the cutoff process at the zero solvent point
doublereal IMS_gamma_k_min_;
//! Parameter in the polyExp cutoff treatment having to do with rate of exp decay
@@ -3464,7 +3464,7 @@ private:
double* etheta, double* etheta_prime) const;
//! Set up a counter variable for keeping track of symmetric binary
- //! interactactions amongst the solute species.
+ //! interactions amongst the solute species.
/*!
* The purpose of this is to squeeze the ij parameters into a
* compressed single counter.
diff --git a/include/cantera/thermo/IdealMolalSoln.h b/include/cantera/thermo/IdealMolalSoln.h
index cc10e1a19..1ff25f8bc 100644
--- a/include/cantera/thermo/IdealMolalSoln.h
+++ b/include/cantera/thermo/IdealMolalSoln.h
@@ -36,7 +36,7 @@ namespace Cantera
* all molality-based activity coefficients are equal
* to one.
*
- * This is a full instanteation of a ThermoPhase object.
+ * This is a full instantiation of a ThermoPhase object.
* The assumption is that the molality-based activity
* coefficient is equal to one. This also implies that
* the osmotic coefficient is equal to one.
@@ -946,7 +946,7 @@ public:
//! gamma_o value for the cutoff process at the zero solvent point
doublereal IMS_gamma_o_min_;
- //! gamma_k minimun for the cutoff process at the zero solvent point
+ //! gamma_k minimum for the cutoff process at the zero solvent point
doublereal IMS_gamma_k_min_;
//! Parameter in the polyExp cutoff treatment having to do with rate of exp decay
diff --git a/include/cantera/thermo/LatticePhase.h b/include/cantera/thermo/LatticePhase.h
index 45af48049..cc217f0b5 100644
--- a/include/cantera/thermo/LatticePhase.h
+++ b/include/cantera/thermo/LatticePhase.h
@@ -23,7 +23,7 @@
namespace Cantera
{
-//! A simple thermoydnamics model for a bulk phase,
+//! A simple thermodynamic model for a bulk phase,
//! assuming a lattice of solid atoms
/*!
* The bulk consists of a matrix of equivalent sites whose molar density
diff --git a/include/cantera/thermo/MargulesVPSSTP.h b/include/cantera/thermo/MargulesVPSSTP.h
index 50d40f2c7..61ec23691 100644
--- a/include/cantera/thermo/MargulesVPSSTP.h
+++ b/include/cantera/thermo/MargulesVPSSTP.h
@@ -66,7 +66,7 @@ namespace Cantera
* All species are defined to have standard states that depend upon both
* the temperature and the pressure. The Margules approximation assumes
* symmetric standard states, where all of the standard state assume
- * that the species are in pure component states at the temperatue
+ * that the species are in pure component states at the temperature
* and pressure of the solution. I don't think it prevents, however,
* some species from being dilute in the solution.
*
@@ -958,7 +958,7 @@ protected:
*/
int formMargules_;
- //! form of the temperatuer dependence of the Margules interaction expression
+ //! form of the temperature dependence of the Margules interaction expression
/*!
* Currently there is only one form -> constant wrt temperature.
*/
diff --git a/include/cantera/thermo/MetalSHEelectrons.h b/include/cantera/thermo/MetalSHEelectrons.h
index d1e68ff84..066768889 100644
--- a/include/cantera/thermo/MetalSHEelectrons.h
+++ b/include/cantera/thermo/MetalSHEelectrons.h
@@ -96,7 +96,7 @@ namespace Cantera
* to the electron, which is the voltage of the metal.
*
*
- * Instanteation of the Class
+ * Instantiation of the Class
*
* The constructor for this phase is located in the default ThermoFactory
* for %Cantera. A new %MetalSHEelectrons object may be created by
@@ -316,7 +316,7 @@ public:
* by kinetics manager classes to compute the forward and
* reverse rates of elementary reactions.
*
- * For a stoichiomeetric substance, there is
+ * For a stoichiometric substance, there is
* only one species, and the generalized concentration is 1.0.
*
* @param c Output array of generalized concentrations. The
@@ -373,7 +373,7 @@ public:
* units are needed. Usually, MKS units are assumed throughout
* the program and in the XML input files.
*
- * The base %ThermoPhase class assigns thedefault quantities
+ * The base %ThermoPhase class assigns the default quantities
* of (kmol/m3) for all species.
* Inherited classes are responsible for overriding the default
* values if necessary.
diff --git a/include/cantera/thermo/MineralEQ3.h b/include/cantera/thermo/MineralEQ3.h
index 16f87bfd8..43d7fc372 100644
--- a/include/cantera/thermo/MineralEQ3.h
+++ b/include/cantera/thermo/MineralEQ3.h
@@ -93,7 +93,7 @@ namespace Cantera
* appear in the rate constant expression, since it's a stoichiometric
* phase and the activity is always equal to 1.0.
*
- * Instanteation of the Class
+ * Instantiation of the Class
*
* The constructor for this phase is NOT located in the default ThermoFactory
* for %Cantera. However, a new %StoichSubstanceSSTP may be created by
@@ -291,7 +291,7 @@ public:
* by kinetics manager classes to compute the forward and
* reverse rates of elementary reactions.
*
- * For a stoichiomeetric substance, there is
+ * For a stoichiometric substance, there is
* only one species, and the generalized concentration is 1.0.
*
* @param c Output array of generalized concentrations. The
@@ -348,7 +348,7 @@ public:
* units are needed. Usually, MKS units are assumed throughout
* the program and in the XML input files.
*
- * The base %ThermoPhase class assigns thedefault quantities
+ * The base %ThermoPhase class assigns the default quantities
* of (kmol/m3) for all species.
* Inherited classes are responsible for overriding the default
* values if necessary.
diff --git a/include/cantera/thermo/MixedSolventElectrolyte.h b/include/cantera/thermo/MixedSolventElectrolyte.h
index a8f6aecf6..8a75a9c9f 100644
--- a/include/cantera/thermo/MixedSolventElectrolyte.h
+++ b/include/cantera/thermo/MixedSolventElectrolyte.h
@@ -67,7 +67,7 @@ namespace Cantera
* All species are defined to have standard states that depend upon both
* the temperature and the pressure. The Margules approximation assumes
* symmetric standard states, where all of the standard state assume
- * that the species are in pure component states at the temperatue
+ * that the species are in pure component states at the temperature
* and pressure of the solution. I don't think it prevents, however,
* some species from being dilute in the solution.
*
@@ -960,7 +960,7 @@ protected:
*/
int formMargules_;
- //! form of the temperatuer dependence of the Margules interaction expression
+ //! form of the temperature dependence of the Margules interaction expression
/*!
* Currently there is only one form -> constant wrt temperature.
*/
diff --git a/include/cantera/thermo/MixtureFugacityTP.h b/include/cantera/thermo/MixtureFugacityTP.h
index d17fc711f..0ff388c79 100644
--- a/include/cantera/thermo/MixtureFugacityTP.h
+++ b/include/cantera/thermo/MixtureFugacityTP.h
@@ -379,7 +379,7 @@ protected:
public:
//! Set the temperature and pressure at the same time
/*!
- * Note this function triggers a reevalulation of the standard
+ * Note this function triggers a reevaluation of the standard
* state quantities.
*
* @param T temperature (kelvin)
diff --git a/include/cantera/thermo/PDSS.h b/include/cantera/thermo/PDSS.h
index 379424070..ccd457a55 100644
--- a/include/cantera/thermo/PDSS.h
+++ b/include/cantera/thermo/PDSS.h
@@ -157,7 +157,7 @@ namespace Cantera
* at higher pressures and temperatures, near the critical point,
* evaluation of the thermodynamics at a pressure of 1 bar may
* lead to situations where the liquid is unstable, i.e., beyond
- * the spinodal curve leading to potentially wrong evalulation
+ * the spinodal curve leading to potentially wrong evaluation
* results.
*
* For cases where the PDSS object doesn't use the SpeciesThermo
@@ -187,11 +187,11 @@ class VPSSMgr;
* species in their standard states at a range of temperatures
* and pressures. The independent variables for this object
* are temperature and pressure.
- * The class may mave a reference to a SpeciesThermo object
+ * The class may have a reference to a SpeciesThermo object
* which handles the calculation of the reference state temperature
* behavior of a subset of species.
*
- * This class is analagous to the SpeciesThermoInterpType
+ * This class is analogous to the SpeciesThermoInterpType
* class, except that the standard state inherently incorporates
* the pressure dependence.
*
diff --git a/include/cantera/thermo/PDSS_HKFT.h b/include/cantera/thermo/PDSS_HKFT.h
index 6d295d2d7..75c5ffe54 100644
--- a/include/cantera/thermo/PDSS_HKFT.h
+++ b/include/cantera/thermo/PDSS_HKFT.h
@@ -36,11 +36,11 @@ class WaterProps;
* species in their standard states at a range of temperatures
* and pressures. The independent variables for this object
* are temperature and pressure.
- * The class may mave a reference to a SpeciesThermo object
+ * The class may have a reference to a SpeciesThermo object
* which handles the calculation of the reference state temperature
* behavior of a subset of species.
*
- * This class is analagous to the SpeciesThermoInterpType
+ * This class is analogous to the SpeciesThermoInterpType
* class, except that the standard state inherently incorporates
* the pressure dependence.
*
diff --git a/include/cantera/thermo/PhaseCombo_Interaction.h b/include/cantera/thermo/PhaseCombo_Interaction.h
index a78dc3fb4..a91b23aa4 100644
--- a/include/cantera/thermo/PhaseCombo_Interaction.h
+++ b/include/cantera/thermo/PhaseCombo_Interaction.h
@@ -52,7 +52,7 @@ namespace Cantera
*
* This class is introduced to represent specific conditions observed in thermal batteries.
* HOwever, it may be physically motivated to represent conditions where there may
- * be a mixture of componds that are not "mixed" at the molecular level. Therefore, there
+ * be a mixture of compounds that are not "mixed" at the molecular level. Therefore, there
* is no mixing term.
*
* The lack of a mixing term has profound effects. First, the mole fraction of a species
@@ -68,7 +68,7 @@ namespace Cantera
* All species are defined to have standard states that depend upon both
* the temperature and the pressure. The Margules approximation assumes
* symmetric standard states, where all of the standard state assume
- * that the species are in pure component states at the temperatue
+ * that the species are in pure component states at the temperature
* and pressure of the solution. I don't think it prevents, however,
* some species from being dilute in the solution.
*
@@ -951,7 +951,7 @@ protected:
*/
int formMargules_;
- //! form of the temperatuer dependence of the Margules interaction expression
+ //! form of the temperature dependence of the Margules interaction expression
/*!
* Currently there is only one form -> constant wrt temperature.
*/
diff --git a/include/cantera/thermo/RedlichKisterVPSSTP.h b/include/cantera/thermo/RedlichKisterVPSSTP.h
index 1ba9f1ec5..44f149f1e 100644
--- a/include/cantera/thermo/RedlichKisterVPSSTP.h
+++ b/include/cantera/thermo/RedlichKisterVPSSTP.h
@@ -64,7 +64,7 @@ namespace Cantera
* All species are defined to have standard states that depend upon both
* the temperature and the pressure. The Redlich-Kister approximation assumes
* symmetric standard states, where all of the standard state assume
- * that the species are in pure component states at the temperatue
+ * that the species are in pure component states at the temperature
* and pressure of the solution. I don't think it prevents, however,
* some species from being dilute in the solution.
*
@@ -885,7 +885,7 @@ protected:
//! vector of species indices representing species B in the interaction
/*!
- * Each Redlich-Kisterexcess Gibbs free energy term involves two species, A and B.
+ * Each Redlich-Kister excess Gibbs free energy term involves two species, A and B.
* This vector identifies species B.
*/
std::vector m_pSpecies_B_ij;
@@ -910,7 +910,7 @@ protected:
*/
int formRedlichKister_;
- //! form of the temperatuer dependence of the Redlich-Kister interaction expression
+ //! form of the temperature dependence of the Redlich-Kister interaction expression
/*!
* Currently there is only one form -> constant wrt temperature.
*/
diff --git a/include/cantera/thermo/SpeciesThermoFactory.h b/include/cantera/thermo/SpeciesThermoFactory.h
index 6582725bb..f6e511589 100644
--- a/include/cantera/thermo/SpeciesThermoFactory.h
+++ b/include/cantera/thermo/SpeciesThermoFactory.h
@@ -57,7 +57,7 @@ public:
* It queries the database of species to understand what
* the requirements are for the submodels for all of the
* species in the phase. Then, it picks the SpeciesThermo
- * object to use, and passies it back to the calling routine.
+ * object to use, and passes it back to the calling routine.
* It doesn't load any of the data into the derived
* SpeciesThermo object.
*
@@ -211,7 +211,7 @@ private:
static SpeciesThermoFactory* s_factory;
#if defined(THREAD_SAFE_CANTERA)
- //! Decl of the static mutex variable that locks the %SpeciesThermo factory singelton
+ //! Decl of the static mutex variable that locks the %SpeciesThermo factory singleton
static boost::mutex species_thermo_mutex;
#endif
diff --git a/include/cantera/thermo/SpeciesThermoInterpType.h b/include/cantera/thermo/SpeciesThermoInterpType.h
index 0f72b3025..81e1a4afa 100644
--- a/include/cantera/thermo/SpeciesThermoInterpType.h
+++ b/include/cantera/thermo/SpeciesThermoInterpType.h
@@ -1,7 +1,7 @@
/**
* @file SpeciesThermoInterpType.h
* Pure Virtual Base class for individual species reference state
- * themodynamic managers and text for the spthermo module
+ * thermodynamic managers and text for the spthermo module
* (see \ref spthermo and class \link Cantera::SpeciesThermoInterpType SpeciesThermoInterpType \endlink).
*/
@@ -132,7 +132,7 @@ class VPSSMgr;
* @ingroup thermoprops
*/
-//! Pure Virtual Base class for the thermoydnamic manager for
+//! Pure Virtual Base class for the thermodynamic manager for
//! an individual species' reference state
/*!
* This differs from the SpeciesThermo virtual
@@ -288,8 +288,8 @@ public:
#endif
};
-//! Class for the thermoydnamic manager for an individual species' reference state
-//! which usess the PDSS base class to satisfy the requests.
+//! Class for the thermodynamic manager for an individual species' reference state
+//! which uses the PDSS base class to satisfy the requests.
/*!
*
* This class is a pass-through class for handling thermodynamics calls
diff --git a/include/cantera/thermo/StoichSubstanceSSTP.h b/include/cantera/thermo/StoichSubstanceSSTP.h
index f953de0f5..f32f49a03 100644
--- a/include/cantera/thermo/StoichSubstanceSSTP.h
+++ b/include/cantera/thermo/StoichSubstanceSSTP.h
@@ -92,7 +92,7 @@ namespace Cantera
* appear in the rate constant expression, since it's a stoichiometric
* phase and the activity is always equal to 1.0.
*
- * Instanteation of the Class
+ * Instantiation of the Class
*
* The constructor for this phase is NOT located in the default ThermoFactory
* for %Cantera. However, a new %StoichSubstanceSSTP may be created by
@@ -290,7 +290,7 @@ public:
* by kinetics manager classes to compute the forward and
* reverse rates of elementary reactions.
*
- * For a stoichiomeetric substance, there is
+ * For a stoichiometric substance, there is
* only one species, and the generalized concentration is 1.0.
*
* @param c Output array of generalized concentrations. The
@@ -347,7 +347,7 @@ public:
* units are needed. Usually, MKS units are assumed throughout
* the program and in the XML input files.
*
- * The base %ThermoPhase class assigns thedefault quantities
+ * The base %ThermoPhase class assigns the default quantities
* of (kmol/m3) for all species.
* Inherited classes are responsible for overriding the default
* values if necessary.
diff --git a/include/cantera/thermo/SurfPhase.h b/include/cantera/thermo/SurfPhase.h
index 25a081d97..69cecf6cf 100644
--- a/include/cantera/thermo/SurfPhase.h
+++ b/include/cantera/thermo/SurfPhase.h
@@ -17,7 +17,7 @@
namespace Cantera
{
-//! A simple thermoydnamics model for a surface phase,
+//! A simple thermodynamic model for a surface phase,
//! assuming an ideal solution model.
/*!
* The surface consists of a grid of equivalent sites.
diff --git a/include/cantera/thermo/ThermoFactory.h b/include/cantera/thermo/ThermoFactory.h
index 10e9728e8..76e5f97e5 100644
--- a/include/cantera/thermo/ThermoFactory.h
+++ b/include/cantera/thermo/ThermoFactory.h
@@ -116,7 +116,7 @@ private:
#if defined(THREAD_SAFE_CANTERA)
- //! Decl for locking mutex for thermo factory singelton
+ //! Decl for locking mutex for thermo factory singleton
static boost::mutex thermo_mutex;
#endif
@@ -196,7 +196,7 @@ ThermoPhase* newPhase(std::string infile, std::string id);
* be ready to be used within applications. This routine contains
* some key routines that are used as pass back routines so that
* the phase (and the contents of the XML file) may contain
- * variable paramerizations for the specification of the
+ * variable parameterizations for the specification of the
* species standard states, the equation of state, and the
* specification of other nonidealities. Below, a description
* is presented of the main algorithm for bringing up a %ThermoPhase
@@ -207,7 +207,7 @@ ThermoPhase* newPhase(std::string infile, std::string id);
* are called or direct constructor routines are called that
* instantiate an inherited ThermoPhase object. This object is input
* to this routine, and therefore contains inherited routines that
- * drive the custimation of the initialization process.
+ * drive the customization of the initialization process.
*
* At the start of the routine, we import descriptions of the elements
* that make up the species in a phase.
diff --git a/include/cantera/thermo/VPSSMgr.h b/include/cantera/thermo/VPSSMgr.h
index a666ac8d6..c6d25ee6c 100644
--- a/include/cantera/thermo/VPSSMgr.h
+++ b/include/cantera/thermo/VPSSMgr.h
@@ -156,7 +156,7 @@ class PDSS;
* - VPSSMgr_General
* - standardState model = "General"
* - This model is completely general. Nothing is assumed at this
- * level. Calls consist of loops to PDSS property evalulations.
+ * level. Calls consist of loops to PDSS property evaluations.
* .
* .
*
@@ -520,7 +520,7 @@ public:
* - _updateRefStateThermo()
* - _updateStandardStateThermo()
*
- * An important point to note is that inbetween calls the assumption
+ * An important point to note is that between calls the assumption
* that the underlying PDSS objects will retain their set Temperatures
* and Pressure CAN NOT BE MADE. For efficiency reasons, we may twiddle
* these to get derivatives.
@@ -549,7 +549,7 @@ public:
*/
virtual void setState_P(doublereal P);
- //! Return the temperatue stored in the object
+ //! Return the temperature stored in the object
doublereal temperature() const {
return m_tlast;
}
@@ -775,7 +775,7 @@ public:
* them. This function is called like an onion.
*
* @param vp_ptr Pointer to the VPStandardStateTP standard state
- * @param sp_ptr Poitner to the SpeciesThermo standard state
+ * @param sp_ptr Pointer to the SpeciesThermo standard state
*/
virtual void initAllPtrs(VPStandardStateTP* vp_ptr, SpeciesThermo* sp_ptr);
@@ -843,7 +843,7 @@ protected:
*/
mutable vector_fp m_s0_R;
- //! Vector containing the species referenc molar volumes
+ //! Vector containing the species reference molar volumes
mutable vector_fp m_V0;
/*!
diff --git a/include/cantera/thermo/VPSSMgr_General.h b/include/cantera/thermo/VPSSMgr_General.h
index 0760a32e3..03a62c2bb 100644
--- a/include/cantera/thermo/VPSSMgr_General.h
+++ b/include/cantera/thermo/VPSSMgr_General.h
@@ -271,7 +271,7 @@ public:
* them. This function is called like an onion.
*
* @param vp_ptr Pointer to the VPStandardStateTP standard state
- * @param sp_ptr Poitner to the SpeciesThermo standard state
+ * @param sp_ptr Pointer to the SpeciesThermo standard state
*/
virtual void initAllPtrs(VPStandardStateTP* vp_ptr, SpeciesThermo* sp_ptr);
diff --git a/include/cantera/thermo/VPSSMgr_Water_ConstVol.h b/include/cantera/thermo/VPSSMgr_Water_ConstVol.h
index 7473a74f6..ca55e0884 100644
--- a/include/cantera/thermo/VPSSMgr_Water_ConstVol.h
+++ b/include/cantera/thermo/VPSSMgr_Water_ConstVol.h
@@ -49,7 +49,7 @@ public:
* Initialize the object.
*
* @param vp_ptr Pointer to the VPStandardStateTP standard state
- * @param sp_ptr Poitner to the SpeciesThermo standard state
+ * @param sp_ptr Pointer to the SpeciesThermo standard state
*/
VPSSMgr_Water_ConstVol(VPStandardStateTP* vp_ptr, SpeciesThermo* sp_ptr);
diff --git a/include/cantera/thermo/VPSSMgr_Water_HKFT.h b/include/cantera/thermo/VPSSMgr_Water_HKFT.h
index def6c7354..38b7c392e 100644
--- a/include/cantera/thermo/VPSSMgr_Water_HKFT.h
+++ b/include/cantera/thermo/VPSSMgr_Water_HKFT.h
@@ -211,7 +211,7 @@ public:
* - _updateRefStateThermo()
* - _updateStandardStateThermo()
*
- * An important point to note is that inbetween calls the assumption
+ * An important point to note is that between calls the assumption
* that the underlying PDSS objects will retain their set Temperatures
* and Pressure CAN NOT BE MADE. For efficiency reasons, we may twiddle
* these to get derivatives.
diff --git a/include/cantera/thermo/VPStandardStateTP.h b/include/cantera/thermo/VPStandardStateTP.h
index 724a6bd43..cccdeae65 100644
--- a/include/cantera/thermo/VPStandardStateTP.h
+++ b/include/cantera/thermo/VPStandardStateTP.h
@@ -322,7 +322,7 @@ protected:
public:
//! Set the temperature and pressure at the same time
/*!
- * Note this function triggers a reevalulation of the standard
+ * Note this function triggers a reevaluation of the standard
* state quantities.
*
* @param T temperature (kelvin)
diff --git a/include/cantera/thermo/WaterPropsIAPWS.h b/include/cantera/thermo/WaterPropsIAPWS.h
index 292fe1c23..f02b540b4 100644
--- a/include/cantera/thermo/WaterPropsIAPWS.h
+++ b/include/cantera/thermo/WaterPropsIAPWS.h
@@ -40,7 +40,7 @@ namespace Cantera
//! Class for calculating the equation of state of water.
/*!
*
- * The reference is W. Wagner, A. Prub, "The IAPWS Formulation 1995 for the Themodynamic
+ * The reference is W. Wagner, A. Prub, "The IAPWS Formulation 1995 for the Thermodynamic
* Properties of Ordinary Water Substance for General and Scientific Use,"
* J. Phys. Chem. Ref. Dat, 31, 387, 2002.
*
@@ -357,7 +357,7 @@ public:
* Note this function will return the saturation pressure, given the temperature.
* It will then set the state of the system to the saturation condition. The input
* parameter waterState is used to either specify the liquid state or the
- * gas state at the desired temperatue and saturated pressure.
+ * gas state at the desired temperature and saturated pressure.
*
* If the input temperature, T, is above T_c, this routine will set the internal
* state to T and the pressure to P_c. Then, return P_c.
@@ -387,7 +387,7 @@ public:
//! Returns the Phase State flag for the current state of the object
/*!
* @param checkState If true, this function does a complete check to see where
- * in paramters space we are
+ * in parameters space we are
*
* There are three values:
* WATER_GAS below the critical temperature but below the critical density
diff --git a/include/cantera/thermo/WaterPropsIAPWSphi.h b/include/cantera/thermo/WaterPropsIAPWSphi.h
index 7b5a18104..225ad511e 100644
--- a/include/cantera/thermo/WaterPropsIAPWSphi.h
+++ b/include/cantera/thermo/WaterPropsIAPWSphi.h
@@ -3,7 +3,7 @@
* Header for Lowest level of the classes which support a real water model
* (see class \link Cantera::WaterPropsIAPWS WaterPropsIAPWS\endlink and class \link WaterPropsIAPWSphi WaterPropsIAPWSphi\endlink).
*
- * This class calculates dimensionless quantitites.
+ * This class calculates dimensionless quantities.
*/
/*
* Copyright (2006) Sandia Corporation. Under the terms of
@@ -19,7 +19,7 @@
* the WaterPropsIAPSWSphi class support low level calls for
* the real description of water.
*
- * The reference is W. Wagner, A. Prub, "The IAPWS Formulation 1995 for the Themodynamic
+ * The reference is W. Wagner, A. Prub, "The IAPWS Formulation 1995 for the Thermodynamic
* Properties of Ordinary Water Substance for General and Scientific Use,"
* J. Phys. Chem. Ref. Dat, 31, 387, 2002.
*
@@ -35,7 +35,7 @@ public:
//! Calculate the Phi function, which is the base function
/*!
- * The phi functino is basically the helmholtz free energy
+ * The phi function is basically the helmholtz free energy
* Eqn. (6.4)
* All internal polynomials are recalculated.
*
@@ -86,7 +86,7 @@ public:
* @param tau Dimensionless temperature = T_c/T
* @param delta Dimensionless density = delta = rho / Rho_c
*
- * note: this is done so much, we have a seperate routine.
+ * note: this is done so much, we have a separate routine.
*/
doublereal pressureM_rhoRT(doublereal tau, doublereal delta);
diff --git a/include/cantera/thermo/WaterSSTP.h b/include/cantera/thermo/WaterSSTP.h
index e603f3c89..b48da1d53 100644
--- a/include/cantera/thermo/WaterSSTP.h
+++ b/include/cantera/thermo/WaterSSTP.h
@@ -22,7 +22,7 @@ class WaterProps;
//! Class for single-component water. This is designed to cover just the
//! liquid part of water.
/*!
- * The reference is W. Wagner, A. Prub, "The IAPWS Formulation 1995 for the Themodynamic
+ * The reference is W. Wagner, A. Prub, "The IAPWS Formulation 1995 for the Thermodynamic
* Properties of Ordinary Water Substance for General and Scientific Use,"
* J. Phys. Chem. Ref. Dat, 31, 387, 2002.
*
diff --git a/include/cantera/tpx/Sub.h b/include/cantera/tpx/Sub.h
index bf1f6948c..630ae2d28 100644
--- a/include/cantera/tpx/Sub.h
+++ b/include/cantera/tpx/Sub.h
@@ -131,7 +131,7 @@ public:
double s() { // entropy, J/kg/K
return prop(EvalS);
}
- double f() { // Helmholz function, J/kg
+ double f() { // Helmholtz function, J/kg
return u() - T*s();
}
double g() { // Gibbs function, J/kg
diff --git a/include/cantera/transport/DustyGasTransport.h b/include/cantera/transport/DustyGasTransport.h
index 1f9128331..40c828bad 100644
--- a/include/cantera/transport/DustyGasTransport.h
+++ b/include/cantera/transport/DustyGasTransport.h
@@ -198,7 +198,7 @@ public:
void setPermeability(doublereal B);
//! Return a reference to the transport manager used to compute the gas
- //! binary diffusion coefficients and the visdcosity.
+ //! binary diffusion coefficients and the viscosity.
/*!
* @return Returns a reference to the gas transport object
*/
@@ -217,10 +217,10 @@ protected:
* The DustyGas model is a subordinate model to the gas phase transport model. Here we
* set the gas phase models.
*
- * This is a protected routine, so that initialiation of the Model must occur within Cantera's setup
+ * This is a protected routine, so that initialization of the Model must occur within Cantera's setup
*
* @param phase Pointer to the underlying ThermoPhase model for the gas phase
- * @param gastr Pointer to the underlying Transport model for transport in the gas phse.
+ * @param gastr Pointer to the underlying Transport model for transport in the gas phase.
*/
void initialize(ThermoPhase* phase, Transport* gastr);
diff --git a/include/cantera/transport/LTPspecies.h b/include/cantera/transport/LTPspecies.h
index ac5e3cde6..abdaba271 100644
--- a/include/cantera/transport/LTPspecies.h
+++ b/include/cantera/transport/LTPspecies.h
@@ -301,7 +301,7 @@ public:
* \verbatim \endverbatim node and specifies a type of transport property (like viscosity)
*
*
- * @param propNode Referenc to the XML node that contains the property information.This class
+ * @param propNode Reference to the XML node that contains the property information.This class
* is assumed to be parameterized by reading XML_Node information.
* @param name String containing the species name
* @param tp_ind enum TransportPropertyType containing the property id that this object
@@ -408,7 +408,7 @@ public:
* \verbatim \endverbatim node and specifies a type of transport property (like viscosity).
*
*
- * @param propNode Referenc to the XML node that contains the property information. This class
+ * @param propNode Reference to the XML node that contains the property information. This class
* must be parameterized by reading XML_Node information.
* @param name String containing the species name
* @param tp_ind enum TransportPropertyType containing the property id that this object
@@ -496,7 +496,7 @@ public:
* \verbatim \endverbatim node and specifies a type of transport property (like viscosity).
*
*
- * @param propNode Referenc to the XML node that contains the property information. This class
+ * @param propNode Reference to the XML node that contains the property information. This class
* must be parameterized by reading XML_Node information.
* @param name String containing the species name
* @param tp_ind enum TransportPropertyType containing the property id that this object
diff --git a/include/cantera/transport/LiquidTransport.h b/include/cantera/transport/LiquidTransport.h
index 4604c46e0..e43b50442 100644
--- a/include/cantera/transport/LiquidTransport.h
+++ b/include/cantera/transport/LiquidTransport.h
@@ -31,7 +31,7 @@ class LiquidTransportParams;
//! properties for liquid phases.
/*!
* Liquid Transport is set up with some flexibility in
- * this class. Transport properties like viscostiy
+ * this class. Transport properties like viscosity
* and thermal conductivity are allowed flexibility within
* the constraints of the LiquidTransportProperty and
* LiquidTransportInteractions classes. For species
diff --git a/src/base/application.h b/src/base/application.h
index 48292214f..fa2e1befc 100644
--- a/src/base/application.h
+++ b/src/base/application.h
@@ -329,7 +329,7 @@ protected:
//! Constructor
ThreadMessages() {}
- //! Provide a pointer deferencing overloaded operator
+ //! Provide a pointer dereferencing overloaded operator
/*!
* @return returns a pointer to Messages
*/
diff --git a/src/base/units.h b/src/base/units.h
index b59a8a009..36308261a 100644
--- a/src/base/units.h
+++ b/src/base/units.h
@@ -173,7 +173,7 @@ private:
std::map m_act_u;
#if defined(THREAD_SAFE_CANTERA)
- //! Decl for static locker for Units singelton
+ //! Decl for static locker for Units singleton
static boost::mutex units_mutex;
#endif
diff --git a/src/base/xml.cpp b/src/base/xml.cpp
index d94c14c0b..a4d458477 100644
--- a/src/base/xml.cpp
+++ b/src/base/xml.cpp
@@ -299,7 +299,7 @@ int XML_Reader::findQuotedString(const std::string& s, std::string& rstring) con
/*
* parseTag parses XML tags, i.e., the XML elements that are
- * inbetween angle brackets.
+ * in between angle brackets.
*/
void XML_Reader::parseTag(std::string tag, std::string& name,
std::map& attribs) const
diff --git a/src/converters/thermoFunctions.cpp b/src/converters/thermoFunctions.cpp
index 034b94c0a..20e50825e 100644
--- a/src/converters/thermoFunctions.cpp
+++ b/src/converters/thermoFunctions.cpp
@@ -1,6 +1,6 @@
/**
* @file thermoFunctions.cpp
- * File containing thermo evalulation functions for NASA polynomials,
+ * File containing thermo evaluation functions for NASA polynomials,
* which are used in testing the interpolations.
*/
diff --git a/src/equil/ChemEquil.cpp b/src/equil/ChemEquil.cpp
index 30ea4b5a9..b9016acbb 100644
--- a/src/equil/ChemEquil.cpp
+++ b/src/equil/ChemEquil.cpp
@@ -684,7 +684,7 @@ int ChemEquil::equilibrate(thermo_t& s, const char* XYstr,
plow = pval;
}
- // Determine the new T estimate by linearly intepolation
+ // Determine the new T estimate by linearly interpolating
// between the upper and lower bounds
slope = (phigh - plow)/(tmax - tmin);
dt = (xval - pval)/slope;
@@ -773,7 +773,7 @@ int ChemEquil::equilibrate(thermo_t& s, const char* XYstr,
int info = estimateEP_Brinkley(s, x, elMolesGoal);
if (info != 0) {
if (info == 1) {
- addLogEntry("estimateEP_Brinkley didn't converge in given max interations");
+ addLogEntry("estimateEP_Brinkley didn't converge in given max iterations");
} else if (info == -3) {
addLogEntry("estimateEP_Brinkley had a singular Jacobian. Continuing anyway");
}
diff --git a/src/equil/MultiPhaseEquil.cpp b/src/equil/MultiPhaseEquil.cpp
index b5d506a3e..7e512d713 100644
--- a/src/equil/MultiPhaseEquil.cpp
+++ b/src/equil/MultiPhaseEquil.cpp
@@ -283,7 +283,7 @@ void MultiPhaseEquil::finish()
}
-/// Extimate the initial mole numbers. This is done by running
+/// Estimate the initial mole numbers. This is done by running
/// each reaction as far forward or backward as possible, subject
/// to the constraint that all mole numbers remain
/// non-negative. Reactions for which \f$ \Delta \mu^0 \f$ are
diff --git a/src/equil/vcs_MultiPhaseEquil.cpp b/src/equil/vcs_MultiPhaseEquil.cpp
index 3142b8430..7c4ce2482 100644
--- a/src/equil/vcs_MultiPhaseEquil.cpp
+++ b/src/equil/vcs_MultiPhaseEquil.cpp
@@ -922,7 +922,7 @@ static void print_char(const char letter, const int num)
/*
*
*
- * HKM -> Work on transfering the current value of the voltages into the
+ * HKM -> Work on transferring the current value of the voltages into the
* equilibrium problem.
*/
int vcs_Cantera_to_vprob(Cantera::MultiPhase* mphase,
@@ -956,7 +956,7 @@ int vcs_Cantera_to_vprob(Cantera::MultiPhase* mphase,
int printLvl = vprob->m_printLvl;
/*
- * Loop over the phases, transfering pertinent information
+ * Loop over the phases, transferring pertinent information
*/
int kT = 0;
for (size_t iphase = 0; iphase < totNumPhases; iphase++) {
diff --git a/src/equil/vcs_VolPhase.cpp b/src/equil/vcs_VolPhase.cpp
index ecca50f80..0d8e010b6 100644
--- a/src/equil/vcs_VolPhase.cpp
+++ b/src/equil/vcs_VolPhase.cpp
@@ -953,7 +953,7 @@ double vcs_VolPhase::VolStar_calc_one(size_t kspec) const
// Calculate the partial molar volumes of all species and return the
// total volume
/*
- * Calculates these quantitites internally and then stores them
+ * Calculates these quantities internally and then stores them
*
* @return total volume (m**3)
*/
diff --git a/src/equil/vcs_root1d.cpp b/src/equil/vcs_root1d.cpp
index 848ce999a..7817ccd02 100644
--- a/src/equil/vcs_root1d.cpp
+++ b/src/equil/vcs_root1d.cpp
@@ -309,7 +309,7 @@ QUAD_BAIL:
if ((xnew > x1 && xnew < x2) || (xnew < x1 && xnew > x2)) {
/*
*
- * If we are doing a jump inbetween two points, make sure
+ * If we are doing a jump in between two points, make sure
* the new trial is between 10% and 90% of the distance
* between the old points.
*/
@@ -333,7 +333,7 @@ QUAD_BAIL:
} else {
/*
* If we are venturing into new ground, only allow the step jump
- * to increase by 100% at each interation
+ * to increase by 100% at each iteration
*/
slope = 2.0 * fabs(x2 - x1);
if (fabs(slope) < fabs(xnew - x2)) {
diff --git a/src/kinetics/FalloffFactory.cpp b/src/kinetics/FalloffFactory.cpp
index e02d304bd..8e22c1aa3 100644
--- a/src/kinetics/FalloffFactory.cpp
+++ b/src/kinetics/FalloffFactory.cpp
@@ -594,7 +594,7 @@ class WF93 : public Falloff
public:
- //! Default constructpr
+ //! Default constructor
WF93() {}
//! Destructor
diff --git a/src/kinetics/ImplicitSurfChem.cpp b/src/kinetics/ImplicitSurfChem.cpp
index b4d402e0f..f9146127d 100644
--- a/src/kinetics/ImplicitSurfChem.cpp
+++ b/src/kinetics/ImplicitSurfChem.cpp
@@ -273,7 +273,7 @@ void ImplicitSurfChem::solvePseudoSteadyStateProblem(int ifuncOverride,
/*
* Install a filter for negative concentrations. One of the
- * few ways solvess can fail is if concentrations on input
+ * few ways solveSS can fail is if concentrations on input
* are below zero.
*/
bool rset = false;
diff --git a/src/kinetics/ImplicitSurfChem.h b/src/kinetics/ImplicitSurfChem.h
index df609c2b9..f550d1d15 100644
--- a/src/kinetics/ImplicitSurfChem.h
+++ b/src/kinetics/ImplicitSurfChem.h
@@ -125,7 +125,7 @@ public:
* 4 SFLUX_TRANSIENT
* The default is -1, which means that the program
* will decide.
- * @param timeScaleOverride When a psuedo transient is
+ * @param timeScaleOverride When a pseudo transient is
* selected this value can be used to override
* the default time scale for integration which
* is one.
diff --git a/src/kinetics/InterfaceKinetics.cpp b/src/kinetics/InterfaceKinetics.cpp
index a49cc4376..1dc78404a 100644
--- a/src/kinetics/InterfaceKinetics.cpp
+++ b/src/kinetics/InterfaceKinetics.cpp
@@ -582,8 +582,8 @@ void InterfaceKinetics::applyButlerVolmerCorrection(doublereal* const kf)
// we print out a warning message about this.
/*
* NOTE, there is some discussion about this point.
- * Should we decrease the activiation energy below zero?
- * I don't think this has been decided in any definative way.
+ * Should we decrease the activation energy below zero?
+ * I don't think this has been decided in any definitive way.
* The treatment below is numerically more stable, however.
*/
doublereal eamod;
@@ -635,7 +635,7 @@ void InterfaceKinetics::applyExchangeCurrentDensityFormulation(doublereal* const
}
//====================================================================================================================
/**
- * Update the rates of progress of the reactions in the reaciton
+ * Update the rates of progress of the reactions in the reaction
* mechanism. This routine operates on internal data.
*/
void InterfaceKinetics::getFwdRateConstants(doublereal* kfwd)
@@ -655,7 +655,7 @@ void InterfaceKinetics::getFwdRateConstants(doublereal* kfwd)
//====================================================================================================================
/**
- * Update the rates of progress of the reactions in the reaciton
+ * Update the rates of progress of the reactions in the reaction
* mechanism. This routine operates on internal data.
*/
void InterfaceKinetics::getRevRateConstants(doublereal* krev, bool doIrreversible)
@@ -1396,7 +1396,7 @@ advanceCoverages(doublereal tstep)
* Note, a direct solve is carried out under the hood here,
* to reduce the computational time.
*
- * the integrator object is saved inbetween calls to
+ * the integrator object is saved between calls to
* reduce the computational cost of repeated calls.
*/
void InterfaceKinetics::
diff --git a/src/kinetics/solveSP.cpp b/src/kinetics/solveSP.cpp
index 1b3a8083a..f6bcc6d2f 100644
--- a/src/kinetics/solveSP.cpp
+++ b/src/kinetics/solveSP.cpp
@@ -33,7 +33,7 @@ static doublereal calcWeightedNorm(const doublereal [], const doublereal dx[], s
/***************************************************************************
- * solveSP Class Definitinos
+ * solveSP Class Definitions
***************************************************************************/
// Main constructor
@@ -851,7 +851,7 @@ calc_t(doublereal netProdRateSolnSP[], doublereal XMolSolnSP[],
// Get the interface kinetics associated with this surface
InterfaceKinetics* m_kin = m_objects[isp];
- // Calcuate the start of the species index for surfaces within
+ // Calculate the start of the species index for surfaces within
// the InterfaceKinetics object
size_t surfIndex = m_kin->surfacePhaseIndex();
kstart = m_kin->kineticsSpeciesIndex(0, surfIndex);
diff --git a/src/kinetics/solveSP.h b/src/kinetics/solveSP.h
index fa46bf578..cac446653 100644
--- a/src/kinetics/solveSP.h
+++ b/src/kinetics/solveSP.h
@@ -43,7 +43,7 @@
* initial guess, and accuracy is needed.
* 4: SFLUX_TRANSIENT = The transient calculation is performed here for an
* amount of time specified by "time_scale". It is
- * not garraunted to be time-accurate - just stable
+ * not guaranteed to be time-accurate - just stable
* and fairly fast. The solution after del_t time is
* returned, whether it's converged to a steady
* state or not.
@@ -164,13 +164,13 @@ class InterfaceKinetics;
*
* 4: SFLUX_TRANSIENT = The transient calculation is performed here for an
* amount of time specified by "time_scale". It is
- * not garraunted to be time-accurate - just stable
+ * not guaranteed to be time-accurate - just stable
* and fairly fast. The solution after del_t time is
* returned, whether it's converged to a steady
* state or not. This is a poor man's time stepping
* algorithm.
*
- * Psuedo time stepping algorithm:
+ * Pseudo time stepping algorithm:
* The time step is determined from sdot[], so so that the time step
* doesn't ever change the value of a variable by more than 100%.
*
@@ -364,7 +364,7 @@ private:
*/
void evalSurfLarge(const doublereal* CSolnSP);
- //! Main Function evalulation
+ //! Main Function evaluation
/*!
*
* @param resid output Vector of residuals, length = m_neq
@@ -541,7 +541,7 @@ private:
*/
std::vector m_kinObjIndex;
- //! Vector containing the indecies of the largest species
+ //! Vector containing the indices of the largest species
//! in each surface phase
/*!
* k = m_spSurfLarge[i]
diff --git a/src/numerics/RootFind.cpp b/src/numerics/RootFind.cpp
index d2722141a..51bd5be51 100644
--- a/src/numerics/RootFind.cpp
+++ b/src/numerics/RootFind.cpp
@@ -185,7 +185,7 @@ doublereal RootFind::delXMeaningful(doublereal x1) const
return del;
}
//================================================================================================
-// Calcuated a controlled, nonzero delta between two numbers
+// Calculate a controlled, nonzero delta between two numbers
/*
* The delta is designed to be greater than or equal to delXNonzero(x) defined above
* with the same sign as the original delta. Therefore if you subtract it from either
@@ -622,7 +622,7 @@ int RootFind::solve(doublereal xmin, doublereal xmax, int itmax, doublereal& fun
} else {
/*
* If we are venturing into new ground, only allow the step jump
- * to increase by 50% at each interation, unless the step jump is less than
+ * to increase by 50% at each iteration, unless the step jump is less than
* the user has said that it is ok to take
*/
doublereal xDelMax = 1.5 * fabs(x2 - x1);
diff --git a/src/numerics/SquareMatrix.cpp b/src/numerics/SquareMatrix.cpp
index e36da961d..63e4586d8 100644
--- a/src/numerics/SquareMatrix.cpp
+++ b/src/numerics/SquareMatrix.cpp
@@ -147,7 +147,7 @@ void SquareMatrix::resize(size_t n, size_t m, doublereal v)
//====================================================================================================================
// Multiply A*b and write result to prod.
/*
- * @param b Vector to do the rh multiplcation
+ * @param b Vector to do the rh multiplication
* @param prod OUTPUT vector to receive the result
*/
void SquareMatrix::mult(const doublereal* b, doublereal* prod) const
@@ -157,7 +157,7 @@ void SquareMatrix::mult(const doublereal* b, doublereal* prod) const
//====================================================================================================================
// Multiply b*A and write result to prod.
/*
- * @param b Vector to do the lh multiplcation
+ * @param b Vector to do the lh multiplication
* @param prod OUTPUT vector to receive the result
*/
void SquareMatrix::leftMult(const doublereal* const b, doublereal* const prod) const
diff --git a/src/numerics/solveProb.cpp b/src/numerics/solveProb.cpp
index 8e7cc80e7..34493e675 100644
--- a/src/numerics/solveProb.cpp
+++ b/src/numerics/solveProb.cpp
@@ -30,9 +30,6 @@ namespace Cantera
static doublereal calcWeightedNorm(const doublereal [], const doublereal dx[], size_t);
-/***************************************************************************
- * solveSP Class Definitinos
- ***************************************************************************/
//================================================================================================
// Main constructor
solveProb::solveProb(ResidEval* resid) :
@@ -467,7 +464,7 @@ void solveProb::resjac_eval(std::vector &JacCol,
//================================================================================================
#define APPROACH 0.50
// This function calculates a damping factor for the Newton iteration update
-// vector, dxneg, to insure that all solution components stay within perscribed bounds
+// vector, dxneg, to insure that all solution components stay within prescribed bounds
/*
* The default for this class is that all solution components are bounded between zero and one.
* this is because the original unknowns were mole fractions and surface site fractions.
diff --git a/src/thermo/HMWSoln.cpp b/src/thermo/HMWSoln.cpp
index 26330748b..8f07a1761 100644
--- a/src/thermo/HMWSoln.cpp
+++ b/src/thermo/HMWSoln.cpp
@@ -1408,7 +1408,7 @@ void HMWSoln::setParametersFromXML(const XML_Node& eosdata)
/*
* Get the saturation pressure for a given temperature.
* Note the limitations of this function. Stability considerations
- * concernting multiphase equilibrium are ignored in this
+ * concerning multiphase equilibrium are ignored in this
* calculation. Therefore, the call is made directly to the SS of
* water underneath. The object is put back into its original
* state at the end of the call.
@@ -1839,7 +1839,7 @@ void HMWSoln::initLengths()
}
/**
- * Calcuate the natural log of the molality-based
+ * Calculate the natural log of the molality-based
* activity coefficients.
*
*/
diff --git a/src/thermo/MetalSHEelectrons.cpp b/src/thermo/MetalSHEelectrons.cpp
index 86a048198..3f526719a 100644
--- a/src/thermo/MetalSHEelectrons.cpp
+++ b/src/thermo/MetalSHEelectrons.cpp
@@ -237,7 +237,7 @@ doublereal MetalSHEelectrons::thermalExpansionCoeff() const
//====================================================================================================================
/*
* This method returns the array of generalized
- * concentrations. For a stoichiomeetric substance, there is
+ * concentrations. For a stoichiometric substance, there is
* only one species, and the generalized concentration is 1.0.
*/
void MetalSHEelectrons::
diff --git a/src/thermo/MineralEQ3.cpp b/src/thermo/MineralEQ3.cpp
index f63ff3a0a..794609cd3 100644
--- a/src/thermo/MineralEQ3.cpp
+++ b/src/thermo/MineralEQ3.cpp
@@ -229,7 +229,7 @@ doublereal MineralEQ3::thermalExpansionCoeff() const
/*
* This method returns the array of generalized
- * concentrations. For a stoichiomeetric substance, there is
+ * concentrations. For a stoichiometric substance, there is
* only one species, and the generalized concentration is 1.0.
*/
void MineralEQ3::
diff --git a/src/thermo/MixtureFugacityTP.cpp b/src/thermo/MixtureFugacityTP.cpp
index 127afe684..dff3d3248 100644
--- a/src/thermo/MixtureFugacityTP.cpp
+++ b/src/thermo/MixtureFugacityTP.cpp
@@ -1034,7 +1034,7 @@ int MixtureFugacityTP::corr0(doublereal TKelvin, doublereal pres, doublereal& de
// Returns the Phase State flag for the current state of the object
/*
* @param checkState If true, this function does a complete check to see where
- * in paramters space we are
+ * in parameter space we are
*
* There are three values:
* WATER_GAS below the critical temperature but below the critical density
diff --git a/src/thermo/NasaPoly2.h b/src/thermo/NasaPoly2.h
index c7fd8739e..292058be0 100644
--- a/src/thermo/NasaPoly2.h
+++ b/src/thermo/NasaPoly2.h
@@ -88,7 +88,7 @@ public:
//! Copy Constructor
/*!
- * @param b objecto to be copied.
+ * @param b object to be copied.
*/
NasaPoly2(const NasaPoly2& b) :
m_lowT(b.m_lowT),
@@ -103,7 +103,7 @@ public:
//! Assignment operator
/*!
- * @param b objecto to be copied.
+ * @param b object to be copied.
*/
NasaPoly2& operator=(const NasaPoly2& b) {
if (&b != this) {
diff --git a/src/thermo/StoichSubstanceSSTP.cpp b/src/thermo/StoichSubstanceSSTP.cpp
index b98cc69ea..2eddcfabe 100644
--- a/src/thermo/StoichSubstanceSSTP.cpp
+++ b/src/thermo/StoichSubstanceSSTP.cpp
@@ -215,7 +215,7 @@ doublereal StoichSubstanceSSTP::thermalExpansionCoeff() const
/*
* This method returns the array of generalized
- * concentrations. For a stoichiomeetric substance, there is
+ * concentrations. For a stoichiometric substance, there is
* only one species, and the generalized concentration is 1.0.
*/
void StoichSubstanceSSTP::
diff --git a/src/thermo/SurfPhase.cpp b/src/thermo/SurfPhase.cpp
index 4c7a19d96..a3aedf492 100644
--- a/src/thermo/SurfPhase.cpp
+++ b/src/thermo/SurfPhase.cpp
@@ -1,6 +1,6 @@
/**
* @file SurfPhase.cpp
- * Definitions for a simple thermoydnamics model of a surface phase
+ * Definitions for a simple thermodynamic model of a surface phase
* derived from ThermoPhase, assuming an ideal solution model
* (see \ref thermoprops and class
* \link Cantera::SurfPhase SurfPhase\endlink).
diff --git a/src/thermo/ThermoPhase.cpp b/src/thermo/ThermoPhase.cpp
index 1745c80c5..4c4321efa 100644
--- a/src/thermo/ThermoPhase.cpp
+++ b/src/thermo/ThermoPhase.cpp
@@ -832,7 +832,7 @@ doublereal ThermoPhase::err(std::string msg) const
* of the standard concentrations and generalized concentrations
* for the kth species.
*
- * The base %ThermoPhase class assigns thedefault quantities
+ * The base %ThermoPhase class assigns the default quantities
* of (kmol/m3).
* Inherited classes are responsible for overriding the default
* values if necessary.
diff --git a/src/thermo/VPSSMgrFactory.cpp b/src/thermo/VPSSMgrFactory.cpp
index 52d193be3..b7aa4f22f 100644
--- a/src/thermo/VPSSMgrFactory.cpp
+++ b/src/thermo/VPSSMgrFactory.cpp
@@ -47,7 +47,7 @@ VPSSMgrFactory* VPSSMgrFactory::s_factory = 0;
#if defined(THREAD_SAFE_CANTERA)
// Defn of the static mutex variable that locks the
-// %VPSSMgr factory singelton
+// %VPSSMgr factory singleton
boost::mutex VPSSMgrFactory::vpss_species_thermo_mutex;
#endif
diff --git a/src/thermo/VPSSMgrFactory.h b/src/thermo/VPSSMgrFactory.h
index 218f84296..bac93eb93 100644
--- a/src/thermo/VPSSMgrFactory.h
+++ b/src/thermo/VPSSMgrFactory.h
@@ -158,7 +158,7 @@ private:
#if defined(THREAD_SAFE_CANTERA)
//! Decl of the static mutex variable that locks the
- //! %VPSSMgr factory singelton
+ //! %VPSSMgr factory singleton
static boost::mutex vpss_species_thermo_mutex;
#endif
diff --git a/src/thermo/VPSSMgr_General.cpp b/src/thermo/VPSSMgr_General.cpp
index 4eb96487a..cb2cabfec 100644
--- a/src/thermo/VPSSMgr_General.cpp
+++ b/src/thermo/VPSSMgr_General.cpp
@@ -84,7 +84,7 @@ VPSSMgr* VPSSMgr_General::duplMyselfAsVPSSMgr() const
* them. This function is called like an onion.
*
* @param vp_ptr Pointer to the VPStandardStateTP standard state
- * @param sp_ptr Poitner to the SpeciesThermo standard state
+ * @param sp_ptr Pointer to the SpeciesThermo standard state
*/
void VPSSMgr_General::initAllPtrs(VPStandardStateTP* vp_ptr, SpeciesThermo* sp_ptr)
{
diff --git a/src/thermo/WaterPropsIAPWS.cpp b/src/thermo/WaterPropsIAPWS.cpp
index 5f5d0dc35..827d15f54 100644
--- a/src/thermo/WaterPropsIAPWS.cpp
+++ b/src/thermo/WaterPropsIAPWS.cpp
@@ -518,7 +518,7 @@ corr1(doublereal temperature, doublereal pressure, doublereal& densLiq,
* Note this function will return the saturation pressure, given the temperature.
* It will then set the state of the system to the saturation condition. The input
* parameter waterState is used to either specify the liquid state or the
- * gas state at the desired temperatue and saturated pressure.
+ * gas state at the desired temperature and saturated pressure.
*
* If the input temperature, T, is above T_c, this routine will set the internal
* state to T and the pressure to P_c. Then, return P_c.
@@ -574,7 +574,7 @@ doublereal WaterPropsIAPWS::psat(doublereal temperature, int waterState)
// Returns the Phase State flag for the current state of the object
/*
* @param checkState If true, this function does a complete check to see where
- * in paramters space we are
+ * in parameter space we are
*
* There are three values:
* WATER_GAS below the critical temperature but below the critical density
diff --git a/src/thermo/WaterPropsIAPWSphi.cpp b/src/thermo/WaterPropsIAPWSphi.cpp
index 9c8e2183b..dfec472b5 100644
--- a/src/thermo/WaterPropsIAPWSphi.cpp
+++ b/src/thermo/WaterPropsIAPWSphi.cpp
@@ -652,7 +652,7 @@ doublereal WaterPropsIAPWSphi::phi_d(doublereal tau, doublereal delta)
*
* p/(rhoRT) = delta * phi_d()
*
- * note: this is done so much, we have a seperate routine.
+ * note: this is done so much, we have a separate routine.
*/
doublereal WaterPropsIAPWSphi::pressureM_rhoRT(doublereal tau, doublereal delta)
{
diff --git a/src/transport/AqueousTransport.cpp b/src/transport/AqueousTransport.cpp
index 3e3309ddb..21e9125d1 100644
--- a/src/transport/AqueousTransport.cpp
+++ b/src/transport/AqueousTransport.cpp
@@ -81,7 +81,7 @@ bool AqueousTransport::initLiquid(LiquidTransportParams& tr)
//m_condcoeffs = tr.condcoeffs;
//m_diffcoeffs = tr.diffcoeffs;
cout << "In AqueousTransport::initLiquid we need to replace" << endl
- << "LiquidTransportParams polyniomial coefficients with" << endl
+ << "LiquidTransportParams polynomial coefficients with" << endl
<< "those in LiquidTransportData as in SimpleTransport." << endl;
m_mode = tr.mode_;
@@ -758,7 +758,7 @@ void AqueousTransport::stefan_maxwell_solve()
break;
default:
- printf("uninmplemetnd\n");
+ printf("unimplemented\n");
throw CanteraError("routine", "not done");
break;
}
diff --git a/src/transport/DustyGasTransport.cpp b/src/transport/DustyGasTransport.cpp
index f892bc364..9c64f62e0 100644
--- a/src/transport/DustyGasTransport.cpp
+++ b/src/transport/DustyGasTransport.cpp
@@ -169,10 +169,10 @@ void DustyGasTransport::setParameters(const int type, const int k, const doubler
* The DustyGas model is a subordinate model to the gas phase transport model. Here we
* set the gas phase models.
*
- * This is a protected routine, so that initialiation of the Model must occur within Cantera's setup
+ * This is a protected routine, so that initialization of the Model must occur within Cantera's setup
*
* @param phase Pointer to the underlying ThermoPhase model for the gas phase
- * @param gastr Pointer to the underlying Transport model for transport in the gas phse.
+ * @param gastr Pointer to the underlying Transport model for transport in the gas phase.
*/
void DustyGasTransport::initialize(ThermoPhase* phase, Transport* gastr)
{
@@ -489,7 +489,7 @@ void DustyGasTransport::setPermeability(doublereal B)
}
//====================================================================================================================
// Return a reference to the transport manager used to compute the gas
-// binary diffusion coefficients and the visdcosity.
+// binary diffusion coefficients and the viscosity.
/*
* @return Returns a reference to the gas transport object
*/
diff --git a/src/transport/LTPspecies.cpp b/src/transport/LTPspecies.cpp
index fa5c8885d..fbcb2d282 100644
--- a/src/transport/LTPspecies.cpp
+++ b/src/transport/LTPspecies.cpp
@@ -208,7 +208,7 @@ doublereal LTPspecies_Const::getSpeciesTransProp()
* \verbatim \endverbatim node and specifies a type of transport property (like viscosity)
*
*
- * @param propNode Referenc to the XML node that contains the property information.This class
+ * @param propNode Reference to the XML node that contains the property information.This class
* is assumed to be parameterized by reading XML_Node information.
* @param name String containing the species name
* @param tp_ind enum TransportPropertyType containing the property id that this object
@@ -321,7 +321,7 @@ doublereal LTPspecies_Arrhenius::getSpeciesTransProp()
* \verbatim \endverbatim node and specifies a type of transport property (like viscosity).
*
*
- * @param propNode Referenc to the XML node that contains the property information. This class
+ * @param propNode Reference to the XML node that contains the property information. This class
* must be parameterized by reading XML_Node information.
* @param name String containing the species name
* @param tp_ind enum TransportPropertyType containing the property id that this object
@@ -394,7 +394,7 @@ doublereal LTPspecies_Poly::getSpeciesTransProp()
* \verbatim \endverbatim node and specifies a type of transport property (like viscosity).
*
*
- * @param propNode Referenc to the XML node that contains the property information. This class
+ * @param propNode Reference to the XML node that contains the property information. This class
* must be parameterized by reading XML_Node information.
* @param name String containing the species name
* @param tp_ind enum TransportPropertyType containing the property id that this object
diff --git a/src/transport/LiquidTransport.cpp b/src/transport/LiquidTransport.cpp
index 9d3948c08..15bec42c5 100644
--- a/src/transport/LiquidTransport.cpp
+++ b/src/transport/LiquidTransport.cpp
@@ -1824,7 +1824,7 @@ void LiquidTransport::stefan_maxwell_solve()
break;
default:
- printf("uninmplemetnd\n");
+ printf("unimplemented\n");
throw CanteraError("routine", "not done");
break;
}
diff --git a/src/transport/MultiTransport.cpp b/src/transport/MultiTransport.cpp
index 73a35e41b..d198a8e32 100644
--- a/src/transport/MultiTransport.cpp
+++ b/src/transport/MultiTransport.cpp
@@ -458,7 +458,7 @@ void MultiTransport::getMassFluxes(const doublereal* state1, const doublereal* s
// update the binary diffusion coefficients if necessary
updateDiff_T();
- // If there is a temperature gadient, then get the
+ // If there is a temperature gradient, then get the
// thermal diffusion coefficients
bool addThermalDiffusion = false;
diff --git a/src/transport/TortuosityBase.cpp b/src/transport/TortuosityBase.cpp
index 7d79ceda7..fecb71e22 100644
--- a/src/transport/TortuosityBase.cpp
+++ b/src/transport/TortuosityBase.cpp
@@ -82,7 +82,7 @@ doublereal TortuosityBase::tortuosityFactor(doublereal porosity)
//====================================================================================================================
// The McMillan number is the ratio of the flux-like variable to the value it would have without porous flow.
/*
- * The McMillan number combines the effect of toruosity
+ * The McMillan number combines the effect of tortuosity
* and volume fraction of the transported phase. The net flux
* observed is then the product of the McMillan number and the
* non-porous transport rate. For a conductivity in a non-porous
diff --git a/src/transport/TortuosityBase.h b/src/transport/TortuosityBase.h
index 8a5e7fdbf..48b287065 100644
--- a/src/transport/TortuosityBase.h
+++ b/src/transport/TortuosityBase.h
@@ -24,8 +24,8 @@ namespace Cantera
* Class to compute the increase in diffusive path length associated with
* tortuous path diffusion through, for example, porous media.
* This base class implementation relates tortuosity to volume fraction
- * through a power-law relationship that goes back to Bruggemann. The
- * exponent is referred to as the Bruggemann exponent.
+ * through a power-law relationship that goes back to Bruggeman. The
+ * exponent is referred to as the Bruggeman exponent.
*
* Note that the total diffusional flux is generally written as
*
@@ -45,7 +45,7 @@ class TortuosityBase
{
public:
- //! Default constructor uses Bruggemann exponent of 1.5
+ //! Default constructor uses Bruggeman exponent of 1.5
TortuosityBase();
//! Copy Constructor
@@ -84,7 +84,7 @@ public:
//! The McMillan number is the ratio of the flux-like
//! variable to the value it would have without porous flow.
/**
- * The McMillan number combines the effect of toruosity
+ * The McMillan number combines the effect of tortuosity
* and volume fraction of the transported phase. The net flux
* observed is then the product of the McMillan number and the
* non-porous transport rate. For a conductivity in a non-porous
diff --git a/src/transport/TortuosityBruggeman.cpp b/src/transport/TortuosityBruggeman.cpp
index 4fdc45d26..1aa26a174 100644
--- a/src/transport/TortuosityBruggeman.cpp
+++ b/src/transport/TortuosityBruggeman.cpp
@@ -85,7 +85,7 @@ doublereal TortuosityBruggeman::tortuosityFactor(doublereal porosity)
//====================================================================================================================
// The McMillan number is the ratio of the flux-like variable to the value it would have without porous flow.
/*
- * The McMillan number combines the effect of toruosity
+ * The McMillan number combines the effect of tortuosity
* and volume fraction of the transported phase. The net flux
* observed is then the product of the McMillan number and the
* non-porous transport rate. For a conductivity in a non-porous
diff --git a/src/transport/TortuosityBruggeman.h b/src/transport/TortuosityBruggeman.h
index 2f5c40be8..39aa988b9 100644
--- a/src/transport/TortuosityBruggeman.h
+++ b/src/transport/TortuosityBruggeman.h
@@ -24,8 +24,8 @@ namespace Cantera
* Class to compute the increase in diffusive path length associated with
* tortuous path diffusion through, for example, porous media.
* This base class implementation relates tortuosity to volume fraction
- * through a power-law relationship that goes back to Bruggemann. The
- * exponent is referred to as the Bruggemann exponent.
+ * through a power-law relationship that goes back to Bruggeman. The
+ * exponent is referred to as the Bruggeman exponent.
*
* Note that the total diffusional flux is generally written as
*
@@ -45,7 +45,7 @@ class TortuosityBruggeman : public TortuosityBase
{
public:
- //! Default constructor uses Bruggemann exponent of 1.5
+ //! Default constructor uses Bruggeman exponent of 1.5
/*!
* @param setPower Exponent in the Bruggeman factor. The default is 1.5
*/
@@ -87,7 +87,7 @@ public:
//! The McMillan number is the ratio of the flux-like
//! variable to the value it would have without porous flow.
/**
- * The McMillan number combines the effect of toruosity
+ * The McMillan number combines the effect of tortuosity
* and volume fraction of the transported phase. The net flux
* observed is then the product of the McMillan number and the
* non-porous transport rate. For a conductivity in a non-porous
@@ -98,7 +98,7 @@ public:
protected:
- //! Bruggemann exponent: power to which the tortuosity depends on the volume fraction
+ //! Bruggeman exponent: power to which the tortuosity depends on the volume fraction
doublereal expBrug_;
};
diff --git a/src/transport/TortuosityMaxwell.cpp b/src/transport/TortuosityMaxwell.cpp
index 2c1425a07..3454996b8 100644
--- a/src/transport/TortuosityMaxwell.cpp
+++ b/src/transport/TortuosityMaxwell.cpp
@@ -84,7 +84,7 @@ doublereal TortuosityMaxwell::tortuosityFactor(doublereal porosity)
//====================================================================================================================
// The McMillan number is the ratio of the flux-like variable to the value it would have without porous flow.
/*
- * The McMillan number combines the effect of toruosity
+ * The McMillan number combines the effect of tortuosity
* and volume fraction of the transported phase. The net flux
* observed is then the product of the McMillan number and the
* non-porous transport rate. For a conductivity in a non-porous
diff --git a/src/transport/TortuosityMaxwell.h b/src/transport/TortuosityMaxwell.h
index ef7a11ade..5d4ed8e17 100644
--- a/src/transport/TortuosityMaxwell.h
+++ b/src/transport/TortuosityMaxwell.h
@@ -84,7 +84,7 @@ public:
//! The McMillan number is the ratio of the flux-like
//! variable to the value it would have without porous flow.
/**
- * The McMillan number combines the effect of toruosity
+ * The McMillan number combines the effect of tortuosity
* and volume fraction of the transported phase. The net flux
* observed is then the product of the McMillan number and the
* non-porous transport rate. For a conductivity in a non-porous
diff --git a/src/transport/TortuosityPercolation.cpp b/src/transport/TortuosityPercolation.cpp
index b49f6bc90..3a0aa3f35 100644
--- a/src/transport/TortuosityPercolation.cpp
+++ b/src/transport/TortuosityPercolation.cpp
@@ -88,7 +88,7 @@ doublereal TortuosityPercolation::tortuosityFactor(doublereal porosity)
//====================================================================================================================
// The McMillan number is the ratio of the flux-like variable to the value it would have without porous flow.
/*
- * The McMillan number combines the effect of toruosity
+ * The McMillan number combines the effect of tortuosity
* and volume fraction of the transported phase. The net flux
* observed is then the product of the McMillan number and the
* non-porous transport rate. For a conductivity in a non-porous
diff --git a/src/transport/TortuosityPercolation.h b/src/transport/TortuosityPercolation.h
index 8604e879b..84fe5fa24 100644
--- a/src/transport/TortuosityPercolation.h
+++ b/src/transport/TortuosityPercolation.h
@@ -19,12 +19,12 @@ namespace Cantera
{
//! This class implements transport coefficient corrections
-//! appropriate for porous media where percollation theory applies.
+//! appropriate for porous media where percolation theory applies.
class TortuosityPercolation : public TortuosityBase
{
public:
- //! Default constructor uses Percolationn exponent of 1.5
+ //! Default constructor uses Percolation exponent of 1.5
/*!
* @param setPower Exponent in the Percolation factor. The default is 1.5
*/
@@ -66,7 +66,7 @@ public:
//! The McMillan number is the ratio of the flux-like
//! variable to the value it would have without porous flow.
/*!
- * The McMillan number combines the effect of toruosity
+ * The McMillan number combines the effect of tortuosity
* and volume fraction of the transported phase. The net flux
* observed is then the product of the McMillan number and the
* non-porous transport rate. For a conductivity in a non-porous
diff --git a/src/transport/TransportFactory.cpp b/src/transport/TransportFactory.cpp
index 8c65c7e89..60e312790 100644
--- a/src/transport/TransportFactory.cpp
+++ b/src/transport/TransportFactory.cpp
@@ -239,7 +239,7 @@ TransportFactory::TransportFactory() :
m_models["None"] = None;
//m_models["Radiative"] = cRadiative;
- m_tranPropMap["viscostiy"] = TP_VISCOSITY;
+ m_tranPropMap["viscosity"] = TP_VISCOSITY;
m_tranPropMap["ionConductivity"] = TP_IONCONDUCTIVITY;
m_tranPropMap["mobilityRatio"] = TP_MOBILITYRATIO;
m_tranPropMap["selfDiffusion"] = TP_SELFDIFFUSION;
diff --git a/include/cantera/transport/Tortuosity.h b/include/cantera/transport/Tortuosity.h
index 58d6cbb26..556e9c9a3 100644
--- a/include/cantera/transport/Tortuosity.h
+++ b/include/cantera/transport/Tortuosity.h
@@ -22,8 +22,8 @@ namespace Cantera
* Class to compute the increase in diffusive path length associated with
* tortuous path diffusion through, for example, porous media.
* This base class implementation relates tortuosity to volume fraction
- * through a power-law relationship that goes back to Bruggemann. The
- * exponent is referred to as the Bruggemann exponent.
+ * through a power-law relationship that goes back to Bruggeman. The
+ * exponent is referred to as the Bruggeman exponent.
*
* Note that the total diffusional flux is generally written as
*
@@ -43,7 +43,7 @@ class Tortuosity
{
public:
- //! Default constructor uses Bruggemann exponent of 1.5
+ //! Default constructor uses Bruggeman exponent of 1.5
Tortuosity(double setPower = 1.5) : expBrug_(setPower) {
}
@@ -53,14 +53,14 @@ public:
* This method returns \f$ 1/\tau^2 \f$ in the description of the
* flux \f$ \phi C_T D_i \nabla X_i / \tau^2 \f$.
*/
- virtual double toruosityFactor(double porosity) {
+ virtual double tortuosityFactor(double porosity) {
return pow(porosity, expBrug_ - 1.0);
}
//! The McMillan number is the ratio of the flux-like
//! variable to the value it would have without porous flow.
/**
* The McMillan number combines the effect of toruosity
* and volume fraction of the transported phase. The net flux
* observed is then the product of the McMillan number and the
* non-porous transport rate. For a conductivity in a non-porous
@@ -72,7 +72,7 @@ public:
}
protected:
- //! Bruggemann exponent: power to which the tortuosity depends on the volume fraction
+ //! Bruggeman exponent: power to which the tortuosity depends on the volume fraction
double expBrug_ ;
};
@@ -80,14 +80,14 @@ protected:
/** This class implements transport coefficient corrections
- * appropriate for porous media where percollation theory applies.
+ * appropriate for porous media where percolation theory applies.
* It is derived from the Tortuosity class.
*/
class TortuosityPercolation : public Tortuosity
{
public:
- //! Default constructor uses Bruggemann exponent of 1.5
+ //! Default constructor uses Bruggeman exponent of 1.5
TortuosityPercolation(double percolationThreshold = 0.4, double conductivityExponent = 2.0) : percolationThreshold_(percolationThreshold), conductivityExponent_(conductivityExponent) {
}
@@ -97,14 +97,14 @@ public:
* This method returns \f$ 1/\tau^2 \f$ in the description of the
* flux \f$ \phi C_T D_i \nabla X_i / \tau^2 \f$.
*/
- double toruosityFactor(double porosity) {
+ double tortuosityFactor(double porosity) {
return McMillan(porosity) / porosity;
}
//! The McMillan number is the ratio of the flux-like
//! variable to the value it would have without porous flow.
/**
* The McMillan number combines the effect of toruosity
* and volume fraction of the transported phase. The net flux
* observed is then the product of the McMillan number and the
* non-porous transport rate. For a conductivity in a non-porous
@@ -152,7 +152,7 @@ class TortuosityMaxwell : public Tortuosity
{
public:
- //! Default constructor uses Bruggemann exponent of 1.5
+ //! Default constructor uses Bruggeman exponent of 1.5
TortuosityMaxwell(double relativeConductivites = 0.0) : relativeConductivites_(relativeConductivites) {
}
@@ -162,14 +162,14 @@ public:
* This method returns \f$ 1/\tau^2 \f$ in the description of the
* flux \f$ \phi C_T D_i \nabla X_i / \tau^2 \f$.
*/
- double toruosityFactor(double porosity) {
+ double tortuosityFactor(double porosity) {
return McMillan(porosity) / porosity;
}
//! The McMillan number is the ratio of the flux-like
//! variable to the value it would have without porous flow.
/**
* The McMillan number combines the effect of toruosity
* and volume fraction of the transported phase. The net flux
* observed is then the product of the McMillan number and the
* non-porous transport rate. For a conductivity in a non-porous
@@ -53,14 +53,14 @@ public:
//! variable to the value it would have without porous flow.
/**
- * The McMillan number combines the effect of toruosity
+ * The McMillan number combines the effect of tortuosity
* and volume fraction of the transported phase. The net flux
* observed is then the product of the McMillan number and the
@@ -97,14 +97,14 @@ public:
//! variable to the value it would have without porous flow.
/**
- * The McMillan number combines the effect of toruosity
+ * The McMillan number combines the effect of tortuosity
* and volume fraction of the transported phase. The net flux
* observed is then the product of the McMillan number and the
@@ -162,14 +162,14 @@ public:
//! variable to the value it would have without porous flow.
/**
- * The McMillan number combines the effect of toruosity
+ * The McMillan number combines the effect of tortuosity
* and volume fraction of the transported phase. The net flux
* observed is then the product of the McMillan number and the